AbstractActionManager class abstract

class AbstractActionManager

Implemented types
Implementers
Annotations
  • @JS.new()

Constructors

AbstractActionManager()

Properties

actions ↔ List<IAction>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
HasPickTriggers → bool
no setter
hasPickTriggers → bool
no setter
hasPointerTriggers → bool
no setter
HasTriggers → bool
no setter
hoverCursor ↔ String
getter/setter pair
isRecursive ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
override
hasSpecificTrigger(num trigger, [bool parameterPredicate(dynamic parameter)]) → bool
hasSpecificTriggers(List<num> triggers) → bool
hasSpecificTriggers2(num triggerA, num triggerB) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processTrigger(num trigger, [IActionEvent evt]) → void
registerAction(IAction action) → IAction
serialize(String name) → dynamic
toString() → String
A string representation of this object.
inherited
unregisterAction(IAction action) → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

HasSpecificTrigger(num trigger) → bool