Animatable class

class Animatable

Annotations
  • @JS.new()

Constructors

Animatable(Scene scene, dynamic target, [num fromFrame, num toFrame, bool loopAnimation, num speedRatio, dynamic onAnimationEnd, List<Animation> animations, dynamic onAnimationLoop, bool isAdditive])

Properties

animationStarted ↔ bool
getter/setter pair
disposeOnEnd ↔ bool
getter/setter pair
fromFrame ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAdditive ↔ bool
getter/setter pair
loopAnimation ↔ bool
getter/setter pair
masterFrame → num
no setter
onAnimationEnd ↔ dynamic
getter/setter pair
onAnimationEndObservable ↔ Observable<Animatable>
getter/setter pair
onAnimationLoop ↔ dynamic
getter/setter pair
onAnimationLoopObservable ↔ Observable<Animatable>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speedRatio ↔ num
getter/setter pair
syncRoot → Animatable
no setter
target ↔ dynamic
getter/setter pair
toFrame ↔ num
getter/setter pair
weight ↔ num
getter/setter pair

Methods

appendAnimations(dynamic target, List<Animation> animations) → void
disableBlending() → void
enableBlending(num blendingSpeed) → void
getAnimationByTargetProperty(String property) → Animation
getAnimations() → List<RuntimeAnimation>
getRuntimeAnimationByTargetProperty(String property) → RuntimeAnimation
goToFrame(num frame) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
reset() → void
restart() → void
stop([String animationName, bool targetMask(dynamic parameter)]) → void
syncWith(Animatable root) → Animatable
toString() → String
A string representation of this object.
inherited
waitAsync() → Promise<Animatable>

Operators

operator ==(Object other) → bool
The equality operator.
inherited