AutoRotationBehavior class

class AutoRotationBehavior

Implemented types
Annotations
  • @JS.new()

Constructors

AutoRotationBehavior()

Properties

hashCode → int
The hash code for this object.
no setterinherited
idleRotationSpeed ↔ num
getter/setter pair
idleRotationSpinupTime ↔ num
getter/setter pair
idleRotationWaitTime ↔ num
getter/setter pair
name ↔ String
getter/setter pairoverride
rotationInProgress → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zoomStopsAnimation ↔ bool
getter/setter pair

Methods

attach(ArcRotateCamera target) → void
override
detach() → void
override
init() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited