AxisScaleGizmo class

class AxisScaleGizmo

Inheritance
Annotations
  • @JS.new()

Constructors

AxisScaleGizmo(Vector3 dragAxis, [Color3 color, UtilityLayerRenderer gizmoLayer, ScaleGizmo parent, num thickness])

Properties

attachedMesh ↔ AbstractMesh
getter/setter pairinherited
attachedNode ↔ Node
getter/setter pairinherited
dragBehavior ↔ PointerDragBehavior
getter/setter pair
gizmoLayer ↔ UtilityLayerRenderer
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isEnabled ↔ bool
getter/setter pair
isHovered → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleRatio ↔ num
getter/setter pairinherited
sensitivity ↔ num
getter/setter pair
snapDistance ↔ num
getter/setter pair
uniformScaling ↔ bool
getter/setter pair
updateGizmoPositionToMatchAttachedMesh ↔ bool
getter/setter pairinherited
updateGizmoRotationToMatchAttachedMesh ↔ bool
getter/setter pairinherited
updateScale ↔ bool
getter/setter pairinherited

Methods

dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCustomMesh(Mesh mesh) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited