Bone class

class Bone

Inheritance
Annotations
  • @JS.new()

Constructors

Bone(String name, Skeleton skeleton, [Bone parentBone, Matrix localMatrix, Matrix restPose, Matrix baseMatrix, num index])

Properties

animations ↔ List<Animation>
getter/setter pairinherited
behaviors → List<Behavior<Node>>
no setterinherited
doNotSerialize ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pairinherited
metadata ↔ dynamic
getter/setter pairinherited
name ↔ String
getter/setter pairinherited
onDispose ← void Function()
no getterinherited
onDisposeObservable ↔ Observable<Node>
getter/setter pairinherited
onReady ↔ void Function(Node node)
getter/setter pairinherited
parent ↔ Node
getter/setter pairinherited
reservedDataStore ↔ dynamic
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String
getter/setter pairinherited
uniqueId ↔ num
getter/setter pairinherited
worldMatrixFromCache → Matrix
no setterinherited

Methods

addBehavior(Behavior<Node> behavior) → Node
inherited
computeWorldMatrix([bool force]) → Matrix
inherited
createAnimationRange(String name, num from, num to) → void
inherited
deleteAnimationRange(String name, [bool deleteFrames]) → void
inherited
dispose([bool doNotRecurse, bool disposeMaterialAndTextures]) → void
inherited
getAnimationByName(String name) → Animation
inherited
getBehaviorByName(String name) → Behavior<Node>
inherited
getChildMeshes([bool directDescendantsOnly, bool predicate(Node node)]) → List<AbstractMesh>
inherited
getChildren([bool predicate(Node node), bool directDescendantsOnly]) → List<Node>
inherited
getClassName() → String
inherited
getDescendants([bool directDescendantsOnly, bool predicate(Node node)]) → List<Node>
inherited
getEngine() → Engine
inherited
getScene() → Scene
inherited
getWorldMatrix() → Matrix
inherited
isDescendantOf(Node ancestor) → bool
inherited
isDisposed() → bool
inherited
isEnabled([bool checkAncestors]) → bool
inherited
isReady([bool completeCheck]) → bool
inherited
isSynchronized() → bool
inherited
isSynchronizedWithParent() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeBehavior(Behavior<Node> behavior) → Node
inherited
serializeAnimationRanges() → dynamic
inherited
setEnabled(bool value) → void
inherited
toString() → String
A string representation of this object.
inherited
updateCache([bool force]) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited