BoundingBox class

class BoundingBox

Implemented types
Annotations
  • @JS.new()

Constructors

BoundingBox(Vector3 min, Vector3 max, [Matrix worldMatrix])

Properties

center → Vector3
no setter
centerWorld → Vector3
no setter
directions → List<Vector3>
no setter
extendSize → Vector3
no setter
extendSizeWorld → Vector3
no setter
hashCode → int
The hash code for this object.
no setterinherited
maximum → Vector3
no setter
maximumWorld → Vector3
no setter
minimum → Vector3
no setter
minimumWorld → Vector3
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vectors → List<Vector3>
no setter
vectorsWorld → List<Vector3>
no setter

Methods

getWorldMatrix() → Matrix
intersectsMinMax(Vector3 min, Vector3 max) → bool
intersectsPoint(Vector3 point) → bool
intersectsSphere(BoundingSphere sphere) → bool
isCompletelyInFrustum(List<Plane> frustumPlanes) → bool
override
isInFrustum(List<Plane> frustumPlanes) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reConstruct(Vector3 min, Vector3 max, [Matrix worldMatrix]) → void
scale(num factor) → BoundingBox
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

TmpVector3 → dynamic
no setter

Static Methods

Intersects(BoundingBox box0, BoundingBox box1) → bool
IntersectsSphere(Vector3 minPoint, Vector3 maxPoint, Vector3 sphereCenter, num sphereRadius) → bool
IsCompletelyInFrustum(List<Vector3> boundingVectors, List<Plane> frustumPlanes) → bool
IsInFrustum(List<Vector3> boundingVectors, List<Plane> frustumPlanes) → bool