BoundingInfo class

class BoundingInfo

Implemented types
Annotations
  • @JS.new()

Constructors

BoundingInfo(Vector3 minimum, Vector3 maximum, [Matrix worldMatrix])

Properties

boundingBox → BoundingBox
no setter
boundingSphere → BoundingSphere
no setter
diagonalLength → num
no setter
hashCode → int
The hash code for this object.
no setterinherited
isLocked ↔ bool
getter/setter pair
maximum → Vector3
no setter
minimum → Vector3
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

centerOn(Vector3 center, Vector3 extend) → BoundingInfo
intersects(BoundingInfo boundingInfo, bool precise) → bool
intersectsPoint(Vector3 point) → bool
isCompletelyInFrustum(List<Plane> frustumPlanes) → bool
override
isInFrustum(List<Plane> frustumPlanes) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reConstruct(Vector3 min, Vector3 max, [Matrix worldMatrix]) → void
scale(num factor) → BoundingInfo
toString() → String
A string representation of this object.
inherited
update(Matrix world) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

TmpVector3 → dynamic
no setter