BoundingSphere class

class BoundingSphere

Annotations
  • @JS.new()

Constructors

BoundingSphere(Vector3 min, Vector3 max, [Matrix worldMatrix])

Properties

center → Vector3
no setter
centerWorld → Vector3
no setter
hashCode → int
The hash code for this object.
no setterinherited
maximum → Vector3
no setter
minimum → Vector3
no setter
radius ↔ num
getter/setter pair
radiusWorld ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getWorldMatrix() → Matrix
intersectsPoint(Vector3 point) → bool
isCenterInFrustum(List<Plane> frustumPlanes) → bool
isInFrustum(List<Plane> frustumPlanes) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reConstruct(Vector3 min, Vector3 max, [Matrix worldMatrix]) → void
scale(num factor) → BoundingSphere
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

TmpVector3 → dynamic
no setter

Static Methods

Intersects(BoundingSphere sphere0, BoundingSphere sphere1) → bool