CSG class

class CSG

Annotations
  • @JS.new()

Constructors

CSG()

Properties

hashCode → int
The hash code for this object.
no setterinherited
matrix ↔ Matrix
getter/setter pair
polygons ↔ dynamic
getter/setter pair
position ↔ Vector3
getter/setter pair
rotation ↔ Vector3
getter/setter pair
rotationQuaternion ↔ Quaternion
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaling ↔ Vector3
getter/setter pair

Methods

buildMeshGeometry(String name, [Scene scene, bool keepSubMeshes]) → Mesh
clone() → CSG
copyTransformAttributes(CSG csg) → CSG
intersect(CSG csg) → CSG
intersectInPlace(CSG csg) → void
inverse() → CSG
inverseInPlace() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subtract(CSG csg) → CSG
subtractInPlace(CSG csg) → void
toMesh(String name, [Material material, Scene scene, bool keepSubMeshes]) → Mesh
toString() → String
A string representation of this object.
inherited
union(CSG csg) → CSG
unionInPlace(CSG csg) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

FromPolygons ↔ dynamic
getter/setter pair

Static Methods

FromMesh(Mesh mesh) → CSG