Collider class

class Collider

Annotations
  • @JS.new()

Constructors

Collider()

Properties

collidedMesh ↔ AbstractMesh
getter/setter pair
collisionFound ↔ bool
getter/setter pair
collisionMask ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intersectionPoint ↔ Vector3
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slidePlaneNormal → Vector3
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited