Color3 class

class Color3

Annotations
  • @JS.new()

Constructors

Color3([num r, num g, num b])

Properties

b ↔ num
getter/setter pair
BlackReadOnly → Color3
no setter
g ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
r ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Color3 otherColor) → Color3
addToRef(Color3 otherColor, Color3 result) → Color3
asArray() → List<num>
clone() → Color3
copyFrom(Color3 source) → Color3
copyFromFloats(num r, num g, num b) → Color3
equals(Color3 otherColor) → bool
equalsFloats(num r, num g, num b) → bool
fromArray(List<num> array, [num offset]) → Color3
getClassName() → String
getHashCode() → num
multiply(Color3 otherColor) → Color3
multiplyToRef(Color3 otherColor, Color3 result) → Color3
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scale(num scale) → Color3
scaleAndAddToRef(num scale, Color3 result) → Color3
scaleToRef(num scale, Color3 result) → Color3
set(num r, num g, num b) → Color3
subtract(Color3 otherColor) → Color3
subtractToRef(Color3 otherColor, Color3 result) → Color3
toArray(Float32List array, [num index]) → Color3
toColor4([num alpha]) → Color4
toGammaSpace() → Color3
toGammaSpaceToRef(Color3 convertedColor) → Color3
toHexString() → String
toHSV() → Color3
toHSVToRef(Color3 result) → void
toLinearSpace() → Color3
toLinearSpaceToRef(Color3 convertedColor) → Color3
toLuminance() → num
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

Black() → Color3
Blue() → Color3
FromArray(List<num> array, [num offset]) → Color3
FromArrayToRef(List<num> array, dynamic offset, Color3 result) → void
FromHexString(String hex) → Color3
FromInts(num r, num g, num b) → Color3
Gray() → Color3
Green() → Color3
HSVtoRGBToRef(num hue, num saturation, num value, Color3 result) → void
Lerp(Color3 start, Color3 end, num amount) → Color3
LerpToRef(Color3 left, Color3 right, num amount, Color3 result) → void
Magenta() → Color3
Purple() → Color3
Random() → Color3
Red() → Color3
Teal() → Color3
White() → Color3
Yellow() → Color3