Color4 class

class Color4

Annotations
  • @JS.new()

Constructors

Color4([num r, num g, num b, num a])

Properties

a ↔ num
getter/setter pair
b ↔ num
getter/setter pair
g ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
r ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Color4 right) → Color4
addInPlace(Color4 right) → Color4
asArray() → List<num>
clone() → Color4
copyFrom(Color4 source) → Color4
copyFromFloats(num r, num g, num b, num a) → Color4
equals(Color4 otherColor) → bool
fromArray(List<num> array, [num offset]) → Color4
getClassName() → String
getHashCode() → num
multiply(Color4 color) → Color4
multiplyToRef(Color4 color, Color4 result) → Color4
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scale(num scale) → Color4
scaleAndAddToRef(num scale, Color4 result) → Color4
scaleToRef(num scale, Color4 result) → Color4
set(num r, num g, num b, num a) → Color4
subtract(Color4 right) → Color4
subtractToRef(Color4 right, Color4 result) → Color4
toArray(List<num> array, [num index]) → Color4
toGammaSpace() → Color4
toGammaSpaceToRef(Color4 convertedColor) → Color4
toHexString([bool returnAsColor3]) → String
toLinearSpace() → Color4
toLinearSpaceToRef(Color4 convertedColor) → Color4
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

CheckColors4(List<num> colors, num count) → List<num>
FromArray(List<num> array, [num offset]) → Color4
FromArrayToRef(List<num> array, dynamic offset, Color4 result) → void
FromColor3(Color3 color3, [num alpha]) → Color4
FromHexString(String hex) → Color4
FromInts(num r, num g, num b, num a) → Color4
Lerp(Color4 left, Color4 right, num amount) → Color4
LerpToRef(Color4 left, Color4 right, num amount, Color4 result) → void