DepthCullingState class

class DepthCullingState

Annotations
  • @JS.new()

Constructors

DepthCullingState()

Properties

cull ↔ bool
getter/setter pair
cullFace ↔ num
getter/setter pair
depthFunc ↔ num
getter/setter pair
depthMask ↔ bool
getter/setter pair
depthTest ↔ bool
getter/setter pair
frontFace ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDirty → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zOffset ↔ num
getter/setter pair

Methods

apply(RenderingContext gl) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited