DepthSortedParticle class

class DepthSortedParticle

Annotations
  • @JS.new()

Constructors

DepthSortedParticle(num idx, num ind, num indLength, num materialIndex)

Properties

hashCode → int
The hash code for this object.
no setterinherited
idx ↔ num
getter/setter pair
ind ↔ num
getter/setter pair
indicesLength ↔ num
getter/setter pair
materialIndex ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sqDistance ↔ num
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited