EventState class

class EventState

Annotations
  • @JS.new()

Constructors

EventState(num mask, [bool skipNextObservers, dynamic target, dynamic currentTarget])

Properties

currentTarget ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastReturnValue ↔ dynamic
getter/setter pair
mask ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipNextObservers ↔ bool
getter/setter pair
target ↔ dynamic
getter/setter pair
userInfo ↔ dynamic
getter/setter pair

Methods

initalize(num mask, [bool skipNextObservers, dynamic target, dynamic currentTarget]) → EventState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited