ExponentialEase class

class ExponentialEase

Inheritance
Implemented types
Annotations
  • @JS.new()

Constructors

ExponentialEase([num exponent])

Properties

exponent ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

ease(num gradient) → num
inherited
easeInCore(num gradient) → num
override
getEasingMode() → num
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEasingMode(num easingMode) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited