FramingBehavior class

class FramingBehavior

Implemented types
Annotations
  • @JS.new()

Constructors

FramingBehavior()

Properties

autoCorrectCameraLimitsAndSensibility ↔ bool
getter/setter pair
defaultElevation ↔ num
getter/setter pair
elevationReturnTime ↔ num
getter/setter pair
elevationReturnWaitTime ↔ num
getter/setter pair
framingTime ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isUserIsMoving → bool
no setter
mode ↔ num
getter/setter pair
name ↔ String
getter/setter pairoverride
positionScale ↔ num
getter/setter pair
radiusScale ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zoomStopsAnimation ↔ bool
getter/setter pair

Methods

attach(ArcRotateCamera target) → void
override
detach() → void
override
init() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stopAllAnimations() → void
toString() → String
A string representation of this object.
inherited
zoomOnBoundingInfo(Vector3 minimumWorld, Vector3 maximumWorld, [bool focusOnOriginXZ, void onAnimationEnd()]) → void
zoomOnMesh(AbstractMesh mesh, [bool focusOnOriginXZ, void onAnimationEnd()]) → void
zoomOnMeshesHierarchy(List<AbstractMesh> meshes, [bool focusOnOriginXZ, void onAnimationEnd()]) → void
zoomOnMeshHierarchy(AbstractMesh mesh, [bool focusOnOriginXZ, void onAnimationEnd()]) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

EasingFunction ↔ ExponentialEase
getter/setter pair
EasingMode ↔ num
getter/setter pair
FitFrustumSidesMode ↔ num
getter/setter pair
IgnoreBoundsSizeMode ↔ num
getter/setter pair