Geometry class

class Geometry

Implemented types
Annotations
  • @JS.new()

Constructors

Geometry(String id, Scene scene, [VertexData vertexData, bool updatable, Mesh mesh])

Properties

boundingBias ↔ Vector2
getter/setter pair
delayLoadingFile ↔ String
getter/setter pair
delayLoadState ↔ num
getter/setter pair
doNotSerialize → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
meshes → List<Mesh>
no setter
notifyUpdate ↔ dynamic
getter/setter pair
onGeometryUpdated ↔ void Function(Geometry geometry, String kind)
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toNumberArray ↔ dynamic
getter/setter pair
uniqueId ↔ num
getter/setter pair
useBoundingInfoFromGeometry ↔ bool
getter/setter pair

Methods

applyToMesh(Mesh mesh) → void
copy(String id) → Geometry
dispose() → void
getEngine() → Engine
getIndexBuffer() → DataBuffer
getIndices([bool copyWhenShared, bool forceCopy]) → Int32List
override
getScene() → Scene
getTotalIndices() → num
getTotalVertices() → num
getVertexBuffer(String kind) → VertexBuffer
getVerticesData(String kind, [bool copyWhenShared, bool forceCopy]) → Float32List
override
getVerticesDataKinds() → List<String>
isDisposed() → bool
isReady() → bool
isVertexBufferUpdatable(String kind) → bool
isVerticesDataPresent(String kind) → bool
override
load(Scene scene, [void onLoaded()]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseForMesh(Mesh mesh, [bool shouldDispose]) → void
removeVerticesData(String kind) → void
serialize() → dynamic
serializeVerticeData() → dynamic
setAllVerticesData(VertexData vertexData, [bool updatable]) → void
setIndices(Int32List indices, num totalVertices, [bool updatable]) → void
override
setVerticesBuffer(VertexBuffer buffer, [num totalVertices]) → void
setVerticesData(String kind, Float32List data, bool updatable) → void
override
toLeftHanded() → void
toString() → String
A string representation of this object.
inherited
updateIndices(Int32List indices, [num offset, bool gpuMemoryOnly]) → void
updateVerticesData(String kind, Float32List data, [bool updateExtends, bool makeItUnique]) → void
override
updateVerticesDataDirectly(String kind, ByteBuffer data, num offset, [bool useBytes]) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

CreateGeometryForMesh(Mesh mesh) → Geometry
ExtractFromMesh(Mesh mesh, String id) → Geometry
Parse(dynamic parsedVertexData, Scene scene, String rootUrl) → Geometry
RandomId() → String