Gizmo class

class Gizmo

Implemented types
Implementers
Annotations
  • @JS.new()

Constructors

Gizmo()
Gizmo.args([UtilityLayerRenderer gizmoLayer])

Properties

attachedMesh ↔ AbstractMesh
getter/setter pair
attachedNode ↔ Node
getter/setter pair
gizmoLayer ↔ UtilityLayerRenderer
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isHovered → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleRatio ↔ num
getter/setter pair
updateGizmoPositionToMatchAttachedMesh ↔ bool
getter/setter pair
updateGizmoRotationToMatchAttachedMesh ↔ bool
getter/setter pair
updateScale ↔ bool
getter/setter pair

Methods

dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCustomMesh(Mesh mesh) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

GizmoAxisPointerObserver(UtilityLayerRenderer gizmoLayer, Map<Mesh, GizmoAxisCache> gizmoAxisCache) → Observer<PointerInfo>