GizmoAxisCache class abstract

interface GizmoAxisCache

Annotations
  • @JS.new()

Constructors

GizmoAxisCache()

Properties

active ↔ bool
getter/setter pair
colliderMeshes ↔ List<Mesh>
getter/setter pair
disableMaterial ↔ StandardMaterial
getter/setter pair
gizmoMeshes ↔ List<Mesh>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hoverMaterial ↔ StandardMaterial
getter/setter pair
material ↔ StandardMaterial
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited