IAgentParameters class

interface IAgentParameters

Annotations
  • @JS.new()
  • @anonymous

Constructors

IAgentParameters({num radius, num height, num maxAcceleration, num maxSpeed, num collisionQueryRange, num pathOptimizationRange, num separationWeight})
factory

Properties

collisionQueryRange → num
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → num
no setter
maxAcceleration → num
no setter
maxSpeed → num
no setter
pathOptimizationRange → num
no setter
radius → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
separationWeight → num
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited