IAudioEngine class abstract

interface IAudioEngine

Inheritance
Annotations
  • @JS.new()

Constructors

IAudioEngine()

Properties

audioContext ↔ AudioContext
getter/setter pair
canUseWebAudio ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isMP3supported ↔ bool
getter/setter pair
isOGGsupported ↔ bool
getter/setter pair
masterGain ↔ GainNode
getter/setter pair
onAudioLockedObservable ↔ Observable<IAudioEngine>
getter/setter pair
onAudioUnlockedObservable ↔ Observable<IAudioEngine>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unlocked ↔ bool
getter/setter pair
useCustomUnlockedButton ↔ bool
getter/setter pair
WarnedWebAudioUnsupported ↔ bool
getter/setter pair

Methods

connectToAnalyser(Analyser analyser) → void
dispose() → void
inherited
getGlobalVolume() → num
lock() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setGlobalVolume(num newVolume) → void
toString() → String
A string representation of this object.
inherited
unlock() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited