IEffectFallbacks class abstract

interface IEffectFallbacks

Implementers
Annotations
  • @JS.new()

Constructors

IEffectFallbacks()

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasMoreFallbacks ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(String currentDefines, Effect effect) → String
toString() → String
A string representation of this object.
inherited
unBindMesh() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited