IGetSetVerticesData class abstract

interface IGetSetVerticesData

Implementers
Annotations
  • @JS.new()

Constructors

IGetSetVerticesData()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getIndices([bool copyWhenShared, bool forceCopy]) → Int32List
getVerticesData(String kind, [bool copyWhenShared, bool forceCopy]) → Float32List
isVerticesDataPresent(String kind) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIndices(Int32List indices, num totalVertices, [bool updatable]) → void
setVerticesData(String kind, Float32List data, bool updatable) → void
toString() → String
A string representation of this object.
inherited
updateVerticesData(String kind, Float32List data, [bool updateExtends, bool makeItUnique]) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited