IHighlightLayerOptions class abstract

interface IHighlightLayerOptions

Annotations
  • @JS.new()

Constructors

IHighlightLayerOptions()

Properties

alphaBlendingMode ↔ num
getter/setter pair
blurHorizontalSize ↔ num
getter/setter pair
blurTextureSizeRatio ↔ num
getter/setter pair
blurVerticalSize ↔ num
getter/setter pair
camera ↔ Camera
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isStroke ↔ bool
getter/setter pair
mainTextureFixedSize ↔ num
getter/setter pair
mainTextureRatio ↔ num
getter/setter pair
renderingGroupId ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited