IImageProcessingConfigurationDefines class abstract

interface IImageProcessingConfigurationDefines

Implementers
Annotations
  • @JS.new()

Properties

COLORCURVES ↔ bool
getter/setter pair
COLORGRADING ↔ bool
getter/setter pair
COLORGRADING3D ↔ bool
getter/setter pair
CONTRAST ↔ bool
getter/setter pair
EXPOSURE ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
IMAGEPROCESSING ↔ bool
getter/setter pair
IMAGEPROCESSINGPOSTPROCESS ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
SAMPLER3DBGRMAP ↔ bool
getter/setter pair
SAMPLER3DGREENDEPTH ↔ bool
getter/setter pair
TONEMAPPING ↔ bool
getter/setter pair
TONEMAPPING_ACES ↔ bool
getter/setter pair
VIGNETTE ↔ bool
getter/setter pair
VIGNETTEBLENDMODEMULTIPLY ↔ bool
getter/setter pair
VIGNETTEBLENDMODEOPAQUE ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited