IInspectorOptions class

interface IInspectorOptions

Annotations
  • @JS.new()
  • @anonymous

Constructors

IInspectorOptions({bool overlay, HtmlElement globalRoot, bool showExplorer, bool showInspector, bool embedMode, bool handleResize, bool enablePopup, bool enableClose, List<IExplorerExtensibilityGroup> explorerExtensibility, String inspectorURL, DebugLayerTab initialTab})
factory

Properties

embedMode → bool
no setter
enableClose → bool
no setter
enablePopup → bool
no setter
explorerExtensibility → List<IExplorerExtensibilityGroup>
no setter
globalRoot → HtmlElement
no setter
handleResize → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
initialTab → DebugLayerTab
no setter
inspectorURL → String
no setter
overlay → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showExplorer → bool
no setter
showInspector → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited