ILoadingScreen class abstract

interface ILoadingScreen

Annotations
  • @JS.new()

Constructors

ILoadingScreen()

Properties

displayLoadingUI ↔ void Function()
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hideLoadingUI ↔ void Function()
getter/setter pair
loadingUIBackgroundColor ↔ String
getter/setter pair
loadingUIText ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited