IMaterialSubSurfaceDefines class abstract

interface IMaterialSubSurfaceDefines

Annotations
  • @JS.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
SS_ALBEDOFORREFRACTIONTINT ↔ bool
getter/setter pair
SS_GAMMAREFRACTION ↔ bool
getter/setter pair
SS_LINEARSPECULARREFRACTION ↔ bool
getter/setter pair
SS_LINKREFRACTIONTOTRANSPARENCY ↔ bool
getter/setter pair
SS_LODINREFRACTIONALPHA ↔ bool
getter/setter pair
SS_MASK_FROM_THICKNESS_TEXTURE ↔ bool
getter/setter pair
SS_MASK_FROM_THICKNESS_TEXTURE_GLTF ↔ bool
getter/setter pair
SS_REFRACTION ↔ bool
getter/setter pair
SS_REFRACTIONMAP_3D ↔ bool
getter/setter pair
SS_REFRACTIONMAP_OPPOSITEZ ↔ bool
getter/setter pair
SS_RGBDREFRACTION ↔ bool
getter/setter pair
SS_SCATTERING ↔ bool
getter/setter pair
SS_THICKNESSANDMASK_TEXTURE ↔ bool
getter/setter pair
SS_THICKNESSANDMASK_TEXTUREDIRECTUV ↔ num
getter/setter pair
SS_TRANSLUCENCY ↔ bool
getter/setter pair
SUBSURFACE ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited