INavigationEnginePlugin class abstract

interface INavigationEnginePlugin

Implementers
Annotations
  • @JS.new()

Constructors

INavigationEnginePlugin()

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildFromNavmeshData(Uint8List data) → void
computePath(Vector3 start, Vector3 end) → List<Vector3>
createCrowd(num maxAgents, num maxAgentRadius, Scene scene) → ICrowd
createDebugNavMesh(Scene scene) → Mesh
createNavMesh(List<Mesh> meshes, INavMeshParameters parameters) → void
dispose() → void
getClosestPoint(Vector3 position) → Vector3
getClosestPointToRef(Vector3 position, Vector3 result) → void
getDefaultQueryExtent() → Vector3
getDefaultQueryExtentToRef(Vector3 result) → void
getMaximumSubStepCount() → num
getNavmeshData() → Uint8List
getRandomPointAround(Vector3 position, num maxRadius) → Vector3
getRandomPointAroundToRef(Vector3 position, num maxRadius, Vector3 result) → void
getTimeStep() → num
isSupported() → bool
moveAlong(Vector3 position, Vector3 destination) → Vector3
moveAlongToRef(Vector3 position, Vector3 destination, Vector3 result) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDefaultQueryExtent(Vector3 extent) → void
setMaximumSubStepCount(num newStepCount) → void
setTimeStep(num newTimeStep) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited