IPhysicsEnabledObject class abstract

interface IPhysicsEnabledObject

Annotations
  • @JS.new()

Constructors

IPhysicsEnabledObject()

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent ↔ dynamic
getter/setter pair
position ↔ Vector3
getter/setter pair
rotation ↔ Vector3
getter/setter pair
rotationQuaternion ↔ Quaternion
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaling ↔ Vector3
getter/setter pair

Methods

computeWorldMatrix(bool force) → Matrix
getAbsolutePivotPoint() → Vector3
getAbsolutePosition() → Vector3
getBoundingInfo() → BoundingInfo
getChildMeshes([bool directDescendantsOnly]) → List<AbstractMesh>
getClassName() → String
getIndices() → Int32List
getScene() → Scene
getVerticesData(String kind) → dynamic
getWorldMatrix() → Matrix
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAbsolutePosition(Vector3 absolutePosition) → TransformNode
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited