ISoundOptions class abstract

interface ISoundOptions

Annotations
  • @JS.new()

Constructors

ISoundOptions()

Properties

autoplay ↔ bool
getter/setter pair
distanceModel ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
length ↔ num
getter/setter pair
loop ↔ bool
getter/setter pair
maxDistance ↔ num
getter/setter pair
offset ↔ num
getter/setter pair
playbackRate ↔ num
getter/setter pair
refDistance ↔ num
getter/setter pair
rolloffFactor ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipCodecCheck ↔ bool
getter/setter pair
spatialSound ↔ bool
getter/setter pair
streaming ↔ bool
getter/setter pair
useCustomAttenuation ↔ bool
getter/setter pair
volume ↔ num
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited