ISpriteManager class abstract

interface ISpriteManager

Inheritance
Annotations
  • @JS.new()

Constructors

ISpriteManager()

Properties

cellHeight ↔ num
getter/setter pair
cellWidth ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isPickable ↔ bool
getter/setter pair
layerMask ↔ num
getter/setter pair
name ↔ String
getter/setter pair
renderingGroupId ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scene ↔ Scene
getter/setter pair
sprites ↔ List<Sprite>
getter/setter pair
texture ↔ Texture
getter/setter pair

Methods

dispose() → void
inherited
intersects(Ray ray, Camera camera, [bool predicate(Sprite sprite), bool fastCheck]) → PickingInfo
multiIntersects(Ray ray, Camera camera, [bool predicate(Sprite sprite)]) → List<PickingInfo>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited