ImageProcessingPostProcess class

class ImageProcessingPostProcess

Inheritance
Annotations
  • @JS.new()

Constructors

ImageProcessingPostProcess(String name, dynamic options, [Camera camera, num samplingMode, Engine engine, bool reusable, num textureType, ImageProcessingConfiguration imageProcessingConfiguration])

Properties

colorCurves ↔ ColorCurves
getter/setter pair
colorCurvesEnabled ↔ bool
getter/setter pair
colorGradingEnabled ↔ bool
getter/setter pair
colorGradingTexture ↔ BaseTexture
getter/setter pair
contrast ↔ num
getter/setter pair
exposure ↔ num
getter/setter pair
fromLinearSpace ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageProcessingConfiguration ↔ ImageProcessingConfiguration
getter/setter pair
isSupported → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toneMappingEnabled ↔ bool
getter/setter pair
toneMappingType ↔ num
getter/setter pair
vignetteBlendMode ↔ num
getter/setter pair
vignetteCameraFov ↔ num
getter/setter pair
vignetteCentreX ↔ num
getter/setter pair
vignetteCentreY ↔ num
getter/setter pair
vignetteColor ↔ Color4
getter/setter pair
vignetteEnabled ↔ bool
getter/setter pair
vignetteStretch ↔ num
getter/setter pair
vignetteWeight ↔ num
getter/setter pair

Methods

dispose([Camera camera]) → void
getClassName() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited