InternalTexture class

class InternalTexture

Annotations
  • @JS.new()

Constructors

InternalTexture(ThinEngine engine, InternalTextureSource source, [bool delayAllocation])

Properties

baseDepth ↔ num
getter/setter pair
baseHeight ↔ num
getter/setter pair
baseWidth ↔ num
getter/setter pair
depth ↔ num
getter/setter pair
format ↔ num
getter/setter pair
generateMipMaps ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ num
getter/setter pair
invertY ↔ bool
getter/setter pair
is2DArray ↔ bool
getter/setter pair
is3D ↔ bool
getter/setter pair
isCube ↔ bool
getter/setter pair
isMultiview ↔ bool
getter/setter pair
isReady ↔ bool
getter/setter pair
onLoadedObservable ↔ Observable<InternalTexture>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samples ↔ num
getter/setter pair
samplingMode ↔ num
getter/setter pair
source → InternalTextureSource
no setter
type ↔ num
getter/setter pair
url ↔ String
getter/setter pair
width ↔ num
getter/setter pair

Methods

dispose() → void
getEngine() → ThinEngine
incrementReferences() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateSize(int width, int height, [int depth]) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited