IntersectionInfo class

class IntersectionInfo

Annotations
  • @JS.new()

Constructors

IntersectionInfo(num bu, num bv, num distance)

Properties

bu ↔ num
getter/setter pair
bv ↔ num
getter/setter pair
distance ↔ num
getter/setter pair
faceId ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subMeshId ↔ num
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited