KeyboardInfoPre class

class KeyboardInfoPre

Inheritance
Annotations
  • @JS.new()

Constructors

KeyboardInfoPre(num type, KeyboardEvent event)

Properties

event ↔ KeyboardEvent
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipOnPointerObservable ↔ bool
getter/setter pair
type ↔ num
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited