Layer class

class Layer

Annotations
  • @JS.new()

Constructors

Layer(String name, String imgUrl, Scene scene, [bool isBackground, Color4 color])

Properties

alphaBlendingMode ↔ num
getter/setter pair
alphaTest ↔ bool
getter/setter pair
color ↔ Color4
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isBackground ↔ bool
getter/setter pair
layerMask ↔ num
getter/setter pair
name ↔ String
getter/setter pair
offset ↔ Vector2
getter/setter pair
onAfterRender ← void Function()
no getter
onAfterRenderObservable ↔ Observable<Layer>
getter/setter pair
onBeforeRender ← void Function()
no getter
onBeforeRenderObservable ↔ Observable<Layer>
getter/setter pair
onDispose ← void Function()
no getter
onDisposeObservable ↔ Observable<Layer>
getter/setter pair
renderOnlyInRenderTargetTextures ↔ bool
getter/setter pair
renderTargetTextures ↔ List<RenderTargetTexture>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ Vector2
getter/setter pair
texture ↔ Texture
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited