LensFlare class

class LensFlare

Annotations
  • @JS.new()

Constructors

LensFlare(num size, num position, Color3 color, String imgUrl, LensFlareSystem system)

Properties

alphaMode ↔ num
getter/setter pair
color ↔ Color3
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
position ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ num
getter/setter pair
texture ↔ Texture
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

AddFlare(num size, num position, Color3 color, String imgUrl, LensFlareSystem system) → LensFlare