LensFlareSystem class

class LensFlareSystem

Annotations
  • @JS.new()

Constructors

LensFlareSystem(String name, dynamic emitter, Scene scene)

Properties

borderLimit ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
isEnabled ↔ bool
getter/setter pair
layerMask ↔ num
getter/setter pair
lensFlares ↔ List<LensFlare>
getter/setter pair
meshesSelectionPredicate ↔ bool Function(AbstractMesh node)
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewportBorder ↔ num
getter/setter pair

Methods

computeEffectivePosition(Viewport globalViewport) → bool
dispose() → void
getEmitter() → dynamic
getEmitterPosition() → Vector3
getScene() → Scene
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render() → bool
serialize() → dynamic
setEmitter(dynamic newEmitter) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

Parse(dynamic parsedLensFlareSystem, Scene scene, String rootUrl) → LensFlareSystem