MeshBuilder class

class MeshBuilder

Annotations
  • @JS.new()

Constructors

MeshBuilder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

CreateBox(String name, MeshBuilderCreateBoxOptions options, [Scene scene]) → Mesh
CreateCapsule(String name, [ICreateCapsuleOptions options, Scene scene]) → Mesh
CreateCylinder(String name, MeshBuilderCreateCylinderOptions options, [Scene scene]) → Mesh
CreateDashedLines(String name, MeshBuilderCreateDashedLinesOptions options, [Scene scene]) → LinesMesh
CreateDecal(String name, AbstractMesh sourceMesh, MeshBuilderCreateDecalOptions options) → Mesh
CreateDisc(String name, MeshBuilderCreateDiscOptions options, [Scene scene]) → Mesh
CreateGround(String name, MeshBuilderCreateGroundOptions options, [Scene scene]) → Mesh
CreateGroundFromHeightMap(String name, String url, MeshBuilderCreateGroundFromHeightMapOptions options, [Scene scene]) → GroundMesh
CreateIcoSphere(String name, MeshBuilderCreateIcoSphereOptions options, [Scene scene]) → Mesh
CreateLathe(String name, MeshBuilderCreateLatheOptions options, [Scene scene]) → Mesh
CreateLines(String name, MeshBuilderCreateLinesOptions options, [Scene scene]) → LinesMesh
CreateLineSystem(String name, MeshBuilderCreateLineSystemOptions options, Scene scene) → LinesMesh
CreatePlane(String name, MeshBuilderCreatePlaneOptions options, [Scene scene]) → Mesh
CreatePolygon(String name, MeshBuilderCreatePolygonOptions options, [Scene scene, dynamic earcutInjection]) → Mesh
CreatePolyhedron(String name, MeshBuilderCreatePolyhedronOptions options, [Scene scene]) → Mesh
CreateRibbon(String name, MeshBuilderCreateRibbonOptions options, [Scene scene]) → Mesh
CreateSphere(String name, MeshBuilderCreateSphereOptions options, [Scene scene]) → Mesh
CreateTiledBox(String name, MeshBuilderCreateTiledBoxOptions options, [Scene scene]) → Mesh
CreateTiledGround(String name, MeshBuilderCreateTiledGroundOptions options, [Scene scene]) → Mesh
CreateTiledPlane(String name, MeshBuilderCreateTiledPlaneOptions options, [Scene scene]) → Mesh
CreateTorus(String name, MeshBuilderCreateTorusOptions options, [Scene scene]) → Mesh
CreateTorusKnot(String name, MeshBuilderCreateTorusKnotOptions options, [Scene scene]) → Mesh
CreateTube(String name, MeshBuilderCreateTubeOptions options, [Scene scene]) → Mesh
ExtrudePolygon(String name, MeshBuilderExtrudePolygonOptions options, [Scene scene, dynamic earcutInjection]) → Mesh
ExtrudeShape(String name, MeshBuilderExtrudeShapeOptions options, [Scene scene]) → Mesh
ExtrudeShapeCustom(String name, MeshBuilderExtrudeShapeCustomOptions options, [Scene scene]) → Mesh