MeshBuilderCreateCylinderOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

MeshBuilderCreateCylinderOptions({num height, num diameterTop, num diameterBottom, num diameter, num tessellation, num subdivisions, num arc, List<Color4> faceColors, List<Vector4> faceUV, bool updatable, bool hasRings, bool enclose, num cap, num sideOrientation, Vector4 frontUVs, Vector4 backUVs})
factory

Properties

arc → num
no setter
backUVs → Vector4
no setter
cap → num
no setter
diameter → num
no setter
diameterBottom → num
no setter
diameterTop → num
no setter
enclose → bool
no setter
faceColors → List<Color4>
no setter
faceUV → List<Vector4>
no setter
frontUVs → Vector4
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasRings → bool
no setter
height → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sideOrientation → num
no setter
subdivisions → num
no setter
tessellation → num
no setter
updatable → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited