MeshBuilderCreateGroundFromHeightMapOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

MeshBuilderCreateGroundFromHeightMapOptions({num width, num height, num subdivisions, num minHeight, num maxHeight, Color3 colorFilter, num alphaFilter, bool updatable, void onReady(GroundMesh mesh)})
factory

Properties

alphaFilter → num
no setter
colorFilter → Color3
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → num
no setter
maxHeight → num
no setter
minHeight → num
no setter
onReady → void Function(GroundMesh mesh)
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subdivisions → num
no setter
updatable → bool
no setter
width → num
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited