MeshBuilderCreateLatheOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

MeshBuilderCreateLatheOptions({List<Vector3> shape, num radius, num tessellation, num clip, num arc, bool closed, bool updatable, num sideOrientation, Vector4 frontUVs, Vector4 backUVs, num cap, bool invertUV})
factory

Properties

arc → num
no setter
backUVs → Vector4
no setter
cap → num
no setter
clip → num
no setter
closed → bool
no setter
frontUVs → Vector4
no setter
hashCode → int
The hash code for this object.
no setterinherited
invertUV → bool
no setter
radius → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → List<Vector3>
no setter
sideOrientation → num
no setter
tessellation → num
no setter
updatable → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited