MeshBuilderCreateLinesOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

MeshBuilderCreateLinesOptions({List<Vector3> points, bool updatable, LinesMesh instance, List<Color4> colors, bool useVertexAlpha})
factory

Properties

colors → List<Color4>
no setter
hashCode → int
The hash code for this object.
no setterinherited
instance → LinesMesh
no setter
points → List<Vector3>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatable → bool
no setter
useVertexAlpha → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited