MeshBuilderCreateSphereOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

MeshBuilderCreateSphereOptions({num segments, num diameter, num diameterX, num diameterY, num diameterZ, num arc, num slice, num sideOrientation, Vector4 frontUVs, Vector4 backUVs, bool updatable})
factory

Properties

arc → num
no setter
backUVs → Vector4
no setter
diameter → num
no setter
diameterX → num
no setter
diameterY → num
no setter
diameterZ → num
no setter
frontUVs → Vector4
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segments → num
no setter
sideOrientation → num
no setter
slice → num
no setter
updatable → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited