MeshBuilderCreateTiledGroundOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

MeshBuilderCreateTiledGroundOptions({num xmin, num zmin, num xmax, num zmax, MeshBuilderCreateTiledGroundOptions subdivisions, MeshBuilderCreateTiledGroundOptions precision, bool updatable})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
precision → MeshBuilderCreateTiledGroundOptionsPrecision
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subdivisions → MeshBuilderCreateTiledGroundOptionsSubdivisions
no setter
updatable → bool
no setter
xmax → num
no setter
xmin → num
no setter
zmax → num
no setter
zmin → num
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited