MeshBuilderCreateTubeOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

MeshBuilderCreateTubeOptions({List<Vector3> path, num radius, num tessellation, num radiusFunction(num x, num z), num cap, num arc, bool updatable, num sideOrientation, Vector4 frontUVs, Vector4 backUVs, Mesh instance, bool invertUV})
factory

Properties

arc → num
no setter
backUVs → Vector4
no setter
cap → num
no setter
frontUVs → Vector4
no setter
hashCode → int
The hash code for this object.
no setterinherited
instance → Mesh
no setter
invertUV → bool
no setter
path → List<Vector3>
no setter
radius → num
no setter
radiusFunction → num Function(num x, num z)
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sideOrientation → num
no setter
tessellation → num
no setter
updatable → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited