MeshBuilderExtrudeShapeCustomOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

MeshBuilderExtrudeShapeCustomOptions({List<Vector3> shape, List<Vector3> path, dynamic scaleFunction, dynamic rotationFunction, bool ribbonCloseArray, bool ribbonClosePath, num cap, bool updatable, num sideOrientation, Vector4 frontUVs, Vector4 backUVs, Mesh instance, bool invertUV})
factory

Properties

backUVs → Vector4
no setter
cap → num
no setter
frontUVs → Vector4
no setter
hashCode → int
The hash code for this object.
no setterinherited
instance → Mesh
no setter
invertUV → bool
no setter
path → List<Vector3>
no setter
ribbonCloseArray → bool
no setter
ribbonClosePath → bool
no setter
rotationFunction → dynamic
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleFunction → dynamic
no setter
shape → List<Vector3>
no setter
sideOrientation → num
no setter
updatable → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited