MeshCreateIcoSphereOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

MeshCreateIcoSphereOptions({num radius, bool flat, num subdivisions, num sideOrientation, bool updatable})
factory

Properties

flat → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
radius → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sideOrientation → num
no setter
subdivisions → num
no setter
updatable → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited