MeshCreatePolyhedronOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

MeshCreatePolyhedronOptions({num type, num size, num sizeX, num sizeY, num sizeZ, dynamic custom, List<Vector4> faceUV, List<Color4> faceColors, bool updatable, num sideOrientation})
factory

Properties

custom → dynamic
no setter
faceColors → List<Color4>
no setter
faceUV → List<Vector4>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sideOrientation → num
no setter
size → num
no setter
sizeX → num
no setter
sizeY → num
no setter
sizeZ → num
no setter
type → num
no setter
updatable → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited