MorphTarget class

class MorphTarget

Implemented types
Annotations
  • @JS.new()

Constructors

MorphTarget(String name, [num influence, Scene scene])

Properties

animationPropertiesOverride ↔ AnimationPropertiesOverride
getter/setter pair
animations ↔ List<Animation>
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
hasNormals → bool
no setter
hasPositions → bool
no setter
hasTangents → bool
no setter
hasUVs → bool
no setter
id ↔ String
getter/setter pair
influence ↔ num
getter/setter pair
name ↔ String
getter/setter pair
onInfluenceChanged ↔ Observable<bool>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uniqueId → num
no setter

Methods

clone() → MorphTarget
getClassName() → String
getNormals() → Float32List
getPositions() → Float32List
getTangents() → Float32List
getUVs() → Float32List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() → dynamic
setNormals(Float32List data) → void
setPositions(Float32List data) → void
setTangents(Float32List data) → void
setUVs(Float32List data) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

FromMesh(AbstractMesh mesh, [String name, num influence]) → MorphTarget
Parse(dynamic serializationObject) → MorphTarget