MorphTargetManager class

class MorphTargetManager

Annotations
  • @JS.new()

Constructors

MorphTargetManager([Scene scene])

Properties

enableNormalMorphing ↔ bool
getter/setter pair
enableTangentMorphing ↔ bool
getter/setter pair
enableUVMorphing ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
influences → Float32List
no setter
numInfluencers → num
no setter
numTargets → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsNormals → bool
no setter
supportsTangents → bool
no setter
supportsUVs → bool
no setter
uniqueId → num
no setter
vertexCount → num
no setter

Methods

addTarget(MorphTarget target) → void
clone() → MorphTargetManager
getActiveTarget(num index) → MorphTarget
getTarget(num index) → MorphTarget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeTarget(MorphTarget target) → void
serialize() → dynamic
synchronize() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

Parse(dynamic serializationObject, Scene scene) → MorphTargetManager