Node class

class Node

Implemented types
Implementers
Annotations
  • @JS.new()

Constructors

Node()
Node.args(String name, [Scene scene])

Properties

animations ↔ List<Animation>
getter/setter pair
behaviors → List<Behavior<Node>>
no setter
doNotSerialize ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
metadata ↔ dynamic
getter/setter pair
name ↔ String
getter/setter pair
onDispose ← void Function()
no getter
onDisposeObservable ↔ Observable<Node>
getter/setter pair
onReady ↔ void Function(Node node)
getter/setter pair
parent ↔ Node
getter/setter pair
reservedDataStore ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String
getter/setter pair
uniqueId ↔ num
getter/setter pair
worldMatrixFromCache → Matrix
no setter

Methods

addBehavior(Behavior<Node> behavior) → Node
override
computeWorldMatrix([bool force]) → Matrix
createAnimationRange(String name, num from, num to) → void
deleteAnimationRange(String name, [bool deleteFrames]) → void
dispose([bool doNotRecurse, bool disposeMaterialAndTextures]) → void
getAnimationByName(String name) → Animation
getBehaviorByName(String name) → Behavior<Node>
override
getChildMeshes([bool directDescendantsOnly, bool predicate(Node node)]) → List<AbstractMesh>
getChildren([bool predicate(Node node), bool directDescendantsOnly]) → List<Node>
getClassName() → String
getDescendants([bool directDescendantsOnly, bool predicate(Node node)]) → List<Node>
getEngine() → Engine
getScene() → Scene
getWorldMatrix() → Matrix
isDescendantOf(Node ancestor) → bool
isDisposed() → bool
isEnabled([bool checkAncestors]) → bool
isReady([bool completeCheck]) → bool
isSynchronized() → bool
isSynchronizedWithParent() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeBehavior(Behavior<Node> behavior) → Node
override
serializeAnimationRanges() → dynamic
setEnabled(bool value) → void
toString() → String
A string representation of this object.
inherited
updateCache([bool force]) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

Construct(String type, String name, Scene scene, [dynamic options]) → Node Function()
ParseAnimationRanges(Node node, dynamic parsedNode, Scene scene) → void