Observer<T> class

class Observer

Annotations
  • @JS.new()

Constructors

Observer(void callback(T eventData, EventState eventState), num mask, [dynamic scope])

Properties

callback ↔ void Function(T eventData, EventState eventState)
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mask ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ dynamic
getter/setter pair
unregisterOnNextCall ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited