OutlineRenderer class

class OutlineRenderer

Implemented types
Annotations
  • @JS.new()

Constructors

OutlineRenderer(Scene scene)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scene ↔ Scene
getter/setter pairoverride
zOffset ↔ num
getter/setter pair

Methods

dispose() → void
override
isReady(SubMesh subMesh, bool useInstances) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild() → void
override
register() → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited