PBRBRDFConfiguration class

class PBRBRDFConfiguration

Annotations
  • @JS.new()

Constructors

PBRBRDFConfiguration(void markAllSubMeshesAsMiscDirty())

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useEnergyConservation ↔ bool
getter/setter pair
useSmithVisibilityHeightCorrelated ↔ bool
getter/setter pair
useSpecularGlossinessInputEnergyConservation ↔ bool
getter/setter pair
useSphericalHarmonics ↔ bool
getter/setter pair

Methods

copyTo(PBRBRDFConfiguration brdfConfiguration) → void
getClassName() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(dynamic source, Scene scene, String rootUrl) → void
prepareDefines(IMaterialBRDFDefines defines) → void
serialize() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited