PBRClearCoatConfiguration class

class PBRClearCoatConfiguration

Annotations
  • @JS.new()

Constructors

PBRClearCoatConfiguration(void markAllSubMeshesAsTexturesDirty())

Properties

bumpTexture ↔ BaseTexture
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
indexOfRefraction ↔ num
getter/setter pair
intensity ↔ num
getter/setter pair
isEnabled ↔ bool
getter/setter pair
isTintEnabled ↔ bool
getter/setter pair
remapF0OnInterfaceChange ↔ bool
getter/setter pair
roughness ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texture ↔ BaseTexture
getter/setter pair
textureRoughness ↔ BaseTexture
getter/setter pair
tintColor ↔ Color3
getter/setter pair
tintColorAtDistance ↔ num
getter/setter pair
tintTexture ↔ BaseTexture
getter/setter pair
tintThickness ↔ num
getter/setter pair
useRoughnessFromMainTexture ↔ bool
getter/setter pair

Methods

bindForSubMesh(UniformBuffer uniformBuffer, Scene scene, Engine engine, bool disableBumpMap, bool isFrozen, bool invertNormalMapX, bool invertNormalMapY, [SubMesh subMesh]) → void
copyTo(PBRClearCoatConfiguration clearCoatConfiguration) → void
dispose([bool forceDisposeTextures]) → void
getActiveTextures(List<BaseTexture> activeTextures) → void
getAnimatables(List<IAnimatable> animatables) → void
getClassName() → String
hasTexture(BaseTexture texture) → bool
isReadyForSubMesh(IMaterialClearCoatDefines defines, Scene scene, Engine engine, bool disableBumpMap) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(dynamic source, Scene scene, String rootUrl) → void
prepareDefines(IMaterialClearCoatDefines defines, Scene scene) → void
serialize() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

AddFallbacks(IMaterialClearCoatDefines defines, EffectFallbacks fallbacks, num currentRank) → num
AddSamplers(List<String> samplers) → void
AddUniforms(List<String> uniforms) → void
PrepareUniformBuffer(UniformBuffer uniformBuffer) → void