PBRSheenConfiguration class

class PBRSheenConfiguration

Annotations
  • @JS.new()

Constructors

PBRSheenConfiguration(void markAllSubMeshesAsTexturesDirty())

Properties

albedoScaling ↔ bool
getter/setter pair
color ↔ Color3
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intensity ↔ num
getter/setter pair
isEnabled ↔ bool
getter/setter pair
linkSheenWithAlbedo ↔ bool
getter/setter pair
roughness ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texture ↔ BaseTexture
getter/setter pair
textureRoughness ↔ BaseTexture
getter/setter pair
useRoughnessFromMainTexture ↔ bool
getter/setter pair

Methods

bindForSubMesh(UniformBuffer uniformBuffer, Scene scene, bool isFrozen, [SubMesh subMesh]) → void
copyTo(PBRSheenConfiguration sheenConfiguration) → void
dispose([bool forceDisposeTextures]) → void
getActiveTextures(List<BaseTexture> activeTextures) → void
getAnimatables(List<IAnimatable> animatables) → void
getClassName() → String
hasTexture(BaseTexture texture) → bool
isReadyForSubMesh(IMaterialSheenDefines defines, Scene scene) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(dynamic source, Scene scene, String rootUrl) → void
prepareDefines(IMaterialSheenDefines defines, Scene scene) → void
serialize() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

AddFallbacks(IMaterialSheenDefines defines, EffectFallbacks fallbacks, num currentRank) → num
AddSamplers(List<String> samplers) → void
AddUniforms(List<String> uniforms) → void
PrepareUniformBuffer(UniformBuffer uniformBuffer) → void