PerfCounter class

class PerfCounter

Annotations
  • @JS.new()

Constructors

PerfCounter()

Properties

average → num
no setter
count → num
no setter
current → num
no setter
hashCode → int
The hash code for this object.
no setterinherited
lastSecAverage → num
no setter
max → num
no setter
min → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total → num
no setter

Methods

addCount(num newCount, bool fetchResult) → void
beginMonitoring() → void
endMonitoring([bool newFrame]) → void
fetchNewFrame() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

Enabled ↔ bool
getter/setter pair