PerformanceMonitor class

class PerformanceMonitor

Annotations
  • @JS.new()

Constructors

PerformanceMonitor([num frameSampleSize])

Properties

averageFPS → num
no setter
averageFrameTime → num
no setter
averageFrameTimeVariance → num
no setter
hashCode → int
The hash code for this object.
no setterinherited
instantaneousFPS → num
no setter
instantaneousFrameTime → num
no setter
isEnabled → bool
no setter
isSaturated → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

disable() → void
enable() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
sampleFrame([num timeMs]) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited