PhysicsImpostor class

class PhysicsImpostor

Annotations
  • @JS.new()

Constructors

PhysicsImpostor(IPhysicsEnabledObject object, num type, [PhysicsImpostorParameters _options, dynamic _scene])

Properties

afterStep ↔ void Function()
getter/setter pair
beforeStep ↔ void Function()
getter/setter pair
friction ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDisposed → bool
no setter
mass ↔ num
getter/setter pair
object ↔ IPhysicsEnabledObject
getter/setter pair
onCollideEvent ↔ void Function(PhysicsImpostor collider, PhysicsImpostor collidedWith)
getter/setter pair
parent ↔ PhysicsImpostor
getter/setter pair
physicsBody ↔ dynamic
getter/setter pair
positionIterations ↔ num
getter/setter pair
pressure ↔ num
getter/setter pair
restitution ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segments ↔ num
getter/setter pair
soft ↔ bool
getter/setter pair
stiffness ↔ num
getter/setter pair
type ↔ num
getter/setter pair
uniqueId ↔ num
getter/setter pair
velocityIterations ↔ num
getter/setter pair

Methods

addAnchor(PhysicsImpostor otherImpostor, num width, num height, num influence, bool noCollisionBetweenLinkedBodies) → PhysicsImpostor
addHook(PhysicsImpostor otherImpostor, num length, num influence, bool noCollisionBetweenLinkedBodies) → PhysicsImpostor
addJoint(PhysicsImpostor otherImpostor, PhysicsJoint joint) → PhysicsImpostor
applyForce(Vector3 force, Vector3 contactPoint) → PhysicsImpostor
applyImpulse(Vector3 force, Vector3 contactPoint) → PhysicsImpostor
clone(IPhysicsEnabledObject newObject) → PhysicsImpostor
createJoint(PhysicsImpostor otherImpostor, num jointType, PhysicsJointData jointData) → PhysicsImpostor
dispose() → void
executeNativeFunction(void func(dynamic world, dynamic physicsBody)) → void
forceUpdate() → void
getAngularVelocity() → Vector3
getBoxSizeToRef(Vector3 result) → PhysicsImpostor
getLinearVelocity() → Vector3
getObjectCenter() → Vector3
getObjectExtendSize() → Vector3
getParam(String paramName) → dynamic
getParentsRotation() → Quaternion
getRadius() → num
isBodyInitRequired() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerAfterPhysicsStep(void func(PhysicsImpostor impostor)) → void
registerBeforePhysicsStep(void func(PhysicsImpostor impostor)) → void
registerOnPhysicsCollide(dynamic collideAgainst, void func(PhysicsImpostor collider, PhysicsImpostor collidedWith)) → void
resetUpdateFlags() → void
setAngularVelocity(Vector3 velocity) → void
setDeltaPosition(Vector3 position) → void
setDeltaRotation(Quaternion rotation) → void
setLinearVelocity(Vector3 velocity) → void
setMass(num mass) → void
setParam(String paramName, num value) → void
setScalingUpdated() → void
sleep() → PhysicsImpostor
syncBoneWithImpostor(Bone bone, AbstractMesh boneMesh, Vector3 jointPivot, [num distToJoint, Quaternion adjustRotation]) → void
syncImpostorWithBone(Bone bone, AbstractMesh boneMesh, Vector3 jointPivot, [num distToJoint, Quaternion adjustRotation, Vector3 boneAxis]) → void
toString() → String
A string representation of this object.
inherited
unregisterAfterPhysicsStep(void func(PhysicsImpostor impostor)) → void
unregisterBeforePhysicsStep(void func(PhysicsImpostor impostor)) → void
unregisterOnPhysicsCollide(dynamic collideAgainst, void func(PhysicsImpostor collider, dynamic collidedAgainst)) → void
wakeUp() → PhysicsImpostor

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

BoxImpostor ↔ num
getter/setter pair
CapsuleImpostor ↔ num
getter/setter pair
ClothImpostor ↔ num
getter/setter pair
ConvexHullImpostor ↔ num
getter/setter pair
CustomImpostor ↔ num
getter/setter pair
CylinderImpostor ↔ num
getter/setter pair
DEFAULT_OBJECT_SIZE ↔ Vector3
getter/setter pair
HeightmapImpostor ↔ num
getter/setter pair
IDENTITY_QUATERNION ↔ Quaternion
getter/setter pair
MeshImpostor ↔ num
getter/setter pair
NoImpostor ↔ num
getter/setter pair
ParticleImpostor ↔ num
getter/setter pair
PlaneImpostor ↔ num
getter/setter pair
RopeImpostor ↔ num
getter/setter pair
SoftbodyImpostor ↔ num
getter/setter pair
SphereImpostor ↔ num
getter/setter pair