PhysicsJoint class

class PhysicsJoint

Annotations
  • @JS.new()

Constructors

PhysicsJoint(num type, PhysicsJointData jointData)

Properties

hashCode → int
The hash code for this object.
no setterinherited
jointData ↔ PhysicsJointData
getter/setter pair
physicsJoint ↔ dynamic
getter/setter pair
physicsPlugin ← IPhysicsEnginePlugin
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ num
getter/setter pair

Methods

executeNativeFunction(void func(dynamic world, dynamic physicsBody)) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

BallAndSocketJoint ↔ num
getter/setter pair
DistanceJoint ↔ num
getter/setter pair
Hinge2Joint ↔ num
getter/setter pair
HingeJoint ↔ num
getter/setter pair
LockJoint ↔ num
getter/setter pair
PointToPointJoint ↔ num
getter/setter pair
PrismaticJoint ↔ num
getter/setter pair
SliderJoint ↔ num
getter/setter pair
SpringJoint ↔ num
getter/setter pair
UniversalJoint ↔ num
getter/setter pair
WheelJoint ↔ num
getter/setter pair