PhysicsJointData class abstract

interface PhysicsJointData

Annotations
  • @JS.new()

Constructors

PhysicsJointData()

Properties

collision ↔ bool
getter/setter pair
connectedAxis ↔ Vector3
getter/setter pair
connectedPivot ↔ Vector3
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mainAxis ↔ Vector3
getter/setter pair
mainPivot ↔ Vector3
getter/setter pair
nativeParams ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited