Plane class

class Plane

Annotations
  • @JS.new()

Constructors

Plane(num a, num b, num c, num d)

Properties

d ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
normal ↔ Vector3
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asArray() → List<num>
clone() → Plane
copyFromPoints(Vector3 point1, Vector3 point2, Vector3 point3) → Plane
dotCoordinate(Vector3 point) → num
getClassName() → String
getHashCode() → num
isFrontFacingTo(Vector3 direction, num epsilon) → bool
normalize() → Plane
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signedDistanceTo(Vector3 point) → num
toString() → String
A string representation of this object.
inherited
transform(Matrix transformation) → Plane

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

FromArray(List<num> array) → Plane
FromPoints(Vector3 point1, Vector3 point2, Vector3 point3) → Plane
FromPositionAndNormal(Vector3 origin, Vector3 normal) → Plane
SignedDistanceToPlaneFromPositionAndNormal(Vector3 origin, Vector3 normal, Vector3 point) → num