PointerDragBehaviorOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

PointerDragBehaviorOptions({Vector3 dragAxis, Vector3 dragPlaneNormal})
factory

Properties

dragAxis → Vector3
no setter
dragPlaneNormal → Vector3
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited