PointerInfoBase class

class PointerInfoBase

Implementers
Annotations
  • @JS.new()

Constructors

PointerInfoBase()
PointerInfoBase.args(num type, dynamic event)

Properties

event ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ num
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited