PositionGizmo class

class PositionGizmo

Inheritance
Annotations
  • @JS.new()

Constructors

PositionGizmo([UtilityLayerRenderer gizmoLayer, num thickness, GizmoManager gizmoManager])

Properties

attachedMesh ↔ AbstractMesh
getter/setter pairoverride
attachedNode ↔ Node
getter/setter pairoverride
gizmoLayer ↔ UtilityLayerRenderer
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isHovered → bool
no setteroverride
planarGizmoEnabled ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleRatio ↔ num
getter/setter pairoverride
snapDistance ↔ num
getter/setter pair
updateGizmoPositionToMatchAttachedMesh ↔ bool
getter/setter pairinherited
updateGizmoRotationToMatchAttachedMesh ↔ bool
getter/setter pairoverride
updateScale ↔ bool
getter/setter pairinherited
xGizmo ↔ AxisDragGizmo
getter/setter pair
xPlaneGizmo ↔ PlaneDragGizmo
getter/setter pair
yGizmo ↔ AxisDragGizmo
getter/setter pair
yPlaneGizmo ↔ PlaneDragGizmo
getter/setter pair
zGizmo ↔ AxisDragGizmo
getter/setter pair
zPlaneGizmo ↔ PlaneDragGizmo
getter/setter pair

Methods

addToAxisCache(Mesh mesh, GizmoAxisCache cache) → void
dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCustomMesh(Mesh mesh) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited