PostProcessRenderEffect class

class PostProcessRenderEffect

Annotations
  • @JS.new()

Constructors

PostProcessRenderEffect(Engine engine, String name, dynamic getPostProcesses(), [bool singleInstance])

Properties

hashCode → int
The hash code for this object.
no setterinherited
isSupported → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPostProcesses([Camera camera]) → List<PostProcess>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited