PostProcessRenderPipeline class

class PostProcessRenderPipeline

Annotations
  • @JS.new()

Constructors

PostProcessRenderPipeline(Engine engine, String name)

Properties

cameras → List<Camera>
no setter
engine ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inspectableCustomProperties ↔ List<IInspectable>
getter/setter pair
isSupported → bool
no setter
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEffect(PostProcessRenderEffect renderEffect) → void
dispose() → void
getClassName() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setPrePassRenderer(PrePassRenderer prePassRenderer) → bool
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited