PrePassEffectConfiguration class abstract

interface PrePassEffectConfiguration

Implementers
Annotations
  • @JS.new()

Properties

enabled ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pair
postProcess ↔ PostProcess
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texturesRequired ↔ List<num>
getter/setter pair

Methods

createPostProcess() → PostProcess
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited