PrePassRenderer class

class PrePassRenderer

Annotations
  • @JS.new()

Constructors

PrePassRenderer(Scene scene)

Properties

disableGammaTransform ↔ bool
getter/setter pair
enabled → bool
no setter
excludedMaterials ↔ List<Material>
getter/setter pair
excludedSkinnedMesh ↔ List<AbstractMesh>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageProcessingPostProcess ↔ ImageProcessingPostProcess
getter/setter pair
isSupported → bool
no setter
mrtCount ↔ num
getter/setter pair
prePassRT ↔ MultiRenderTarget
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samples ↔ num
getter/setter pair
useGeometryBufferFallback ↔ bool
getter/setter pair

Methods

addEffectConfiguration(PrePassEffectConfiguration cfg) → PrePassEffectConfiguration
bindAttachmentsForEffect(Effect effect, SubMesh subMesh) → void
clear() → void
dispose() → void
getIndex(num type) → num
markAsDirty() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restoreAttachments() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited