Ray class

class Ray

Annotations
  • @JS.new()

Constructors

Ray(Vector3 origin, Vector3 direction, [num length])

Properties

direction ↔ Vector3
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
length ↔ num
getter/setter pair
origin ↔ Vector3
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

intersectionSegment(Vector3 sega, Vector3 segb, num threshold) → num
intersectsAxis(String axis, [num offset]) → Vector3
intersectsBox(BoundingBox box, [num intersectionTreshold]) → bool
intersectsBoxMinMax(Vector3 minimum, Vector3 maximum, [num intersectionTreshold]) → bool
intersectsMesh(AbstractMesh mesh, [bool fastCheck]) → PickingInfo
intersectsMeshes(List<AbstractMesh> meshes, [bool fastCheck, List<PickingInfo> results]) → List<PickingInfo>
intersectsPlane(Plane plane) → num
intersectsSphere(BoundingSphere sphere, [num intersectionTreshold]) → bool
intersectsTriangle(Vector3 vertex0, Vector3 vertex1, Vector3 vertex2) → IntersectionInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
unprojectRayToRef(num sourceX, num sourceY, num viewportWidth, num viewportHeight, Matrix world, Matrix view, Matrix projection) → void
update(num x, num y, num viewportWidth, num viewportHeight, Matrix world, Matrix view, Matrix projection) → Ray

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

rayl ↔ dynamic
getter/setter pair
smallnum ↔ dynamic
getter/setter pair

Static Methods

CreateNew(num x, num y, num viewportWidth, num viewportHeight, Matrix world, Matrix view, Matrix projection) → Ray
CreateNewFromTo(Vector3 origin, Vector3 end, [Matrix world]) → Ray
Transform(Ray ray, Matrix matrix) → Ray
TransformToRef(Ray ray, Matrix matrix, Ray result) → void
Zero() → Ray