RecastJSPlugin class

class RecastJSPlugin

Implemented types
Annotations
  • @JS.new()

Constructors

RecastJSPlugin([dynamic recastInjection])

Properties

bjsRECAST ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pairoverride
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildFromNavmeshData(Uint8List data) → void
override
computePath(Vector3 start, Vector3 end) → List<Vector3>
override
createCrowd(num maxAgents, num maxAgentRadius, Scene scene) → ICrowd
override
createDebugNavMesh(Scene scene) → Mesh
override
createNavMesh(List<Mesh> meshes, INavMeshParameters parameters) → void
override
dispose() → void
override
getClosestPoint(Vector3 position) → Vector3
override
getClosestPointToRef(Vector3 position, Vector3 result) → void
override
getDefaultQueryExtent() → Vector3
override
getDefaultQueryExtentToRef(Vector3 result) → void
override
getMaximumSubStepCount() → num
override
getNavmeshData() → Uint8List
override
getRandomPointAround(Vector3 position, num maxRadius) → Vector3
override
getRandomPointAroundToRef(Vector3 position, num maxRadius, Vector3 result) → void
override
getTimeStep() → num
override
isSupported() → bool
override
moveAlong(Vector3 position, Vector3 destination) → Vector3
override
moveAlongToRef(Vector3 position, Vector3 destination, Vector3 result) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDefaultQueryExtent(Vector3 extent) → void
override
setMaximumSubStepCount(num newStepCount) → void
override
setTimeStep(num newTimeStep) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited