ReflectionProbe class

class ReflectionProbe

Annotations
  • @JS.new()

Constructors

ReflectionProbe(String name, num size, Scene scene, [bool generateMipMaps, bool useFloat])

Properties

cubeTexture → RenderTargetTexture
no setter
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pair
position ↔ Vector3
getter/setter pair
refreshRate ↔ num
getter/setter pair
renderList → List<AbstractMesh>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samples ↔ num
getter/setter pair

Methods

attachToMesh(AbstractMesh mesh) → void
dispose() → void
getClassName() → String
getScene() → Scene
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() → dynamic
setRenderingAutoClearDepthStencil(num renderingGroupId, bool autoClearDepthStencil) → void
toString([bool fullDetails]) → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

Parse(dynamic parsedReflectionProbe, Scene scene, String rootUrl) → ReflectionProbe