RuntimeAnimation class

class RuntimeAnimation

Annotations
  • @JS.new()

Constructors

RuntimeAnimation(dynamic target, Animation animation, Scene scene, Animatable host)

Properties

animation → Animation
no setter
currentFrame → num
no setter
currentValue → dynamic
no setter
hashCode → int
The hash code for this object.
no setterinherited
isAdditive → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → dynamic
no setter
targetPath → String
no setter
weight → num
no setter

Methods

animate(num delay, num from, num to, bool loop, num speedRatio, [num weight]) → bool
dispose() → void
goToFrame(num frame) → void
isStopped() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset([bool restoreOriginal]) → void
setValue(dynamic currentValue, num weight) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited