Scalar class

class Scalar

Annotations
  • @JS.new()

Constructors

Scalar()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

TwoPi ↔ num
getter/setter pair

Static Methods

Clamp(num value, [num min, num max]) → num
DeltaAngle(num current, num target) → num
Denormalize(num normalized, num min, num max) → num
Hermite(num value1, num tangent1, num value2, num tangent2, num amount) → num
InverseLerp(num a, num b, num value) → num
Lerp(num start, num end, num amount) → num
LerpAngle(num start, num end, num amount) → num
Log2(num value) → num
MoveTowards(num current, num target, num maxDelta) → num
MoveTowardsAngle(num current, num target, num maxDelta) → num
Normalize(num value, num min, num max) → num
NormalizeRadians(num angle) → num
PercentToRange(num percent, num min, num max) → num
PingPong(num tx, num length) → num
RandomRange(num min, num max) → num
RangeToPercent(num number, num min, num max) → num
Repeat(num value, num length) → num
Sign(num value) → num
SmoothStep(num from, num to, num tx) → num
ToHex(num i) → String
WithinEpsilon(num a, num b, [num epsilon]) → bool