ScaleGizmo class

class ScaleGizmo

Inheritance
Annotations
  • @JS.new()

Constructors

ScaleGizmo([UtilityLayerRenderer gizmoLayer, num thickness, GizmoManager gizmoManager])

Properties

attachedMesh ↔ AbstractMesh
getter/setter pairoverride
attachedNode ↔ Node
getter/setter pairoverride
gizmoLayer ↔ UtilityLayerRenderer
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isHovered → bool
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleRatio ↔ num
getter/setter pairoverride
sensitivity ↔ num
getter/setter pair
snapDistance ↔ num
getter/setter pair
uniformScaleGizmo ↔ AxisScaleGizmo
getter/setter pair
updateGizmoPositionToMatchAttachedMesh ↔ bool
getter/setter pairinherited
updateGizmoRotationToMatchAttachedMesh ↔ bool
getter/setter pairoverride
updateScale ↔ bool
getter/setter pairinherited
xGizmo ↔ AxisScaleGizmo
getter/setter pair
yGizmo ↔ AxisScaleGizmo
getter/setter pair
zGizmo ↔ AxisScaleGizmo
getter/setter pair

Methods

addToAxisCache(Mesh mesh, GizmoAxisCache cache) → void
dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCustomMesh(Mesh mesh) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited