SixDofDragBehavior class

class SixDofDragBehavior

Implemented types
Annotations
  • @JS.new()

Constructors

SixDofDragBehavior()

Properties

currentDraggingPointerID ↔ num
getter/setter pair
detachCameraControls ↔ bool
getter/setter pair
dragDeltaRatio ↔ num
getter/setter pair
dragging ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pairoverride
onDragObservable ↔ Observable<void>
getter/setter pair
rotateDraggedObject ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zDragFactor ↔ dynamic
getter/setter pair

Methods

attach(Mesh target) → void
override
detach() → void
override
init() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited