SolidParticle class

class SolidParticle

Annotations
  • @JS.new()

Constructors

SolidParticle(num particleIndex, num particleId, num positionIndex, num indiceIndex, ModelShape model, num shapeId, num idxInShape, SolidParticleSystem sps, [BoundingInfo modelBoundingInfo, num materialIndex])

Properties

alive ↔ bool
getter/setter pair
color ↔ Color4
getter/setter pair
cullingStrategy ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ num
getter/setter pair
idx ↔ num
getter/setter pair
idxInShape ↔ num
getter/setter pair
isVisible ↔ bool
getter/setter pair
materialIndex ↔ num
getter/setter pair
parentId ↔ num
getter/setter pair
pivot ↔ Vector3
getter/setter pair
position ↔ Vector3
getter/setter pair
props ↔ dynamic
getter/setter pair
quaternion ↔ Quaternion
getter/setter pair
rotation ↔ Vector3
getter/setter pair
rotationQuaternion ↔ Quaternion
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ Vector3
getter/setter pair
scaling ↔ Vector3
getter/setter pair
shapeId ↔ num
getter/setter pair
translateFromPivot ↔ bool
getter/setter pair
uvs ↔ Vector4
getter/setter pair
velocity ↔ Vector3
getter/setter pair

Methods

copyToRef(SolidParticle target) → SolidParticle
getRotationMatrix(Matrix m) → void
intersectsMesh(dynamic target) → bool
isInFrustum(List<Plane> frustumPlanes) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited