SolidParticleSystem class

class SolidParticleSystem

Implemented types
Annotations
  • @JS.new()

Constructors

SolidParticleSystem(String name, Scene scene, [SolidParticleSystemOptions options])

Properties

autoUpdateSubMeshes ↔ bool
getter/setter pair
billboard ↔ bool
getter/setter pair
computeBoundingBox ↔ bool
getter/setter pair
computeParticleColor ↔ bool
getter/setter pair
computeParticleRotation ↔ bool
getter/setter pair
computeParticleTexture ↔ bool
getter/setter pair
computeParticleVertex ↔ bool
getter/setter pair
counter ↔ num
getter/setter pair
depthSortedParticles ↔ List<DepthSortedParticle>
getter/setter pair
depthSortParticles ↔ bool
getter/setter pair
expandable → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
isAlwaysVisible ↔ bool
getter/setter pair
isVisibilityBoxLocked ↔ bool
getter/setter pair
materials → List<Material>
no setter
mesh ↔ Mesh
getter/setter pair
multimaterial ↔ MultiMaterial
getter/setter pair
multimaterialEnabled → bool
no setter
name ↔ String
getter/setter pair
nbParticles ↔ num
getter/setter pair
particles ↔ List<SolidParticle>
getter/setter pair
recomputeNormals ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useModelMaterial → bool
no setter
vars ↔ dynamic
getter/setter pair

Methods

addShape(Mesh mesh, num nb, [SolidParticleSystemAddShapeOptions options]) → num
afterUpdateParticles([num start, num stop, bool update]) → void
beforeUpdateParticles([num start, num stop, bool update]) → void
buildMesh() → Mesh
computeSubMeshes() → SolidParticleSystem
digest(Mesh mesh, [SolidParticleSystemDigestOptions options]) → SolidParticleSystem
dispose() → void
override
getParticleById(num id) → SolidParticle
getParticlesByShapeId(num shapeId) → List<SolidParticle>
getParticlesByShapeIdToRef(num shapeId, List<SolidParticle> ref) → SolidParticleSystem
initParticles() → void
insertParticlesFromArray(List<SolidParticle> solidParticleArray) → SolidParticleSystem
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuildMesh([bool reset]) → SolidParticleSystem
recycleParticle(SolidParticle particle) → SolidParticle
refreshVisibleSize() → SolidParticleSystem
removeParticles(num start, num end) → List<SolidParticle>
setMultiMaterial(List<Material> materials) → void
setParticles([num start, num end, bool update]) → SolidParticleSystem
setVisibilityBox(num size) → void
toString() → String
A string representation of this object.
inherited
updateParticle(SolidParticle particle) → SolidParticle
updateParticleVertex(SolidParticle particle, SolidParticleVertex vertex, num pt) → SolidParticleSystem

Operators

operator ==(Object other) → bool
The equality operator.
inherited