SolidParticleSystemAddShapeOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

SolidParticleSystemAddShapeOptions({dynamic positionFunction, dynamic vertexFunction, List storage})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
positionFunction → dynamic
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storage → List
no setter
vertexFunction → dynamic
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited