SolidParticleSystemDigestOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

SolidParticleSystemDigestOptions({num facetNb, num number, num delta, List storage})
factory

Properties

delta → num
no setter
facetNb → num
no setter
hashCode → int
The hash code for this object.
no setterinherited
number → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storage → List
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited