SolidParticleSystemOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

SolidParticleSystemOptions({bool updatable, bool isPickable, bool enableDepthSort, bool particleIntersection, bool boundingSphereOnly, num bSphereRadiusFactor, bool expandable, bool useModelMaterial, bool enableMultiMaterial})
factory

Properties

boundingSphereOnly → bool
no setter
bSphereRadiusFactor → num
no setter
enableDepthSort → bool
no setter
enableMultiMaterial → bool
no setter
expandable → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
isPickable → bool
no setter
particleIntersection → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatable → bool
no setter
useModelMaterial → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited