SphericalPolynomial class

class SphericalPolynomial

Annotations
  • @JS.new()

Constructors

SphericalPolynomial()

Properties

hashCode → int
The hash code for this object.
no setterinherited
preScaledHarmonics → SphericalHarmonics
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x ↔ Vector3
getter/setter pair
xx ↔ Vector3
getter/setter pair
xy ↔ Vector3
getter/setter pair
y ↔ Vector3
getter/setter pair
yy ↔ Vector3
getter/setter pair
yz ↔ Vector3
getter/setter pair
z ↔ Vector3
getter/setter pair
zx ↔ Vector3
getter/setter pair
zz ↔ Vector3
getter/setter pair

Methods

addAmbient(Color3 color) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scaleInPlace(num scale) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited