StencilState class

class StencilState

Annotations
  • @JS.new()

Constructors

StencilState()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDirty → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stencilFunc ↔ num
getter/setter pair
stencilFuncMask ↔ num
getter/setter pair
stencilFuncRef ↔ num
getter/setter pair
stencilMask ↔ num
getter/setter pair
stencilOpDepthFail ↔ num
getter/setter pair
stencilOpStencilDepthPass ↔ num
getter/setter pair
stencilOpStencilFail ↔ num
getter/setter pair
stencilTest ↔ bool
getter/setter pair

Methods

apply(RenderingContext gl) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

ALWAYS → num
no setter
KEEP → num
no setter
REPLACE → num
no setter