SubMesh class

class SubMesh

Implemented types
Annotations
  • @JS.new()

Constructors

SubMesh(num materialIndex, num verticesStart, num verticesCount, num indexStart, num indexCount, AbstractMesh mesh, [Mesh renderingMesh, bool createBoundingBox, bool addToMesh])

Properties

effect → Effect
no setter
hashCode → int
The hash code for this object.
no setterinherited
indexCount ↔ num
getter/setter pair
indexStart ↔ num
getter/setter pair
IsGlobal → bool
no setter
materialDefines ↔ MaterialDefines
getter/setter pair
materialIndex ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verticesCount ↔ num
getter/setter pair
verticesStart ↔ num
getter/setter pair

Methods

canIntersects(Ray ray) → bool
clone(AbstractMesh newMesh, [Mesh newRenderingMesh]) → SubMesh
dispose() → void
getBoundingInfo() → BoundingInfo
getClassName() → String
getEffectiveMesh() → AbstractMesh
getMaterial() → Material
getMesh() → AbstractMesh
getRenderingMesh() → Mesh
getReplacementMesh() → AbstractMesh
isCompletelyInFrustum(List<Plane> frustumPlanes) → bool
override
isInFrustum(List<Plane> frustumPlanes) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshBoundingInfo([Float32List data]) → SubMesh
render(bool enableAlphaMode) → SubMesh
setBoundingInfo(BoundingInfo boundingInfo) → SubMesh
setEffect(Effect effect, [MaterialDefines defines]) → void
toString() → String
A string representation of this object.
inherited
updateBoundingInfo(Matrix world) → SubMesh

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

AddToMesh(num materialIndex, num verticesStart, num verticesCount, num indexStart, num indexCount, AbstractMesh mesh, [Mesh renderingMesh, bool createBoundingBox]) → SubMesh
CreateFromIndices(num materialIndex, num startIndex, num indexCount, AbstractMesh mesh, [Mesh renderingMesh]) → SubMesh