SubSurfaceConfiguration class

class SubSurfaceConfiguration

Implemented types
Annotations
  • @JS.new()

Constructors

SubSurfaceConfiguration(Scene scene)

Properties

enabled ↔ bool
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
metersPerUnit ↔ num
getter/setter pair
name ↔ String
getter/setter pairoverride
postProcess ↔ PostProcess
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ssDiffusionD → List<num>
no setter
ssDiffusionProfileColors ↔ List<Color3>
getter/setter pair
ssDiffusionS → List<num>
no setter
ssFilterRadii → List<num>
no setter
texturesRequired ↔ List<num>
getter/setter pairoverride

Methods

addDiffusionProfile(Color3 color) → num
clearAllDiffusionProfiles() → void
createPostProcess() → SubSurfaceScatteringPostProcess
override
dispose() → void
override
getDiffusionProfileParameters(Color3 color) → num
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited