SubSurfaceScatteringPostProcess class

class SubSurfaceScatteringPostProcess

Inheritance
Annotations
  • @JS.new()

Constructors

SubSurfaceScatteringPostProcess(String name, Scene scene, dynamic options, [Camera camera, num samplingMode, Engine engine, bool reusable, num textureType])

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getClassName() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited