ThinEngine class

class ThinEngine

Implementers
Annotations
  • @JS.new()

Constructors

ThinEngine()
ThinEngine.args(dynamic canvasOrContext, [bool antialias, EngineOptions options, bool adaptToDeviceRatio])

Properties

alphaState → AlphaState
no setter
bindBuffer ↔ dynamic
getter/setter pair
cullBackFaces ↔ bool
getter/setter pair
currentViewport → IViewportLike
no setter
depthCullingState → DepthCullingState
no setter
description → String
no setter
disableUniformBuffers ↔ bool
getter/setter pair
disableVertexArrayObjects ↔ bool
getter/setter pair
doNotHandleContextLost ↔ bool
getter/setter pair
emptyCubeTexture → InternalTexture
no setter
emptyTexture → InternalTexture
no setter
emptyTexture2DArray → InternalTexture
no setter
emptyTexture3D → InternalTexture
no setter
enableUnpackFlipYCached ↔ bool
getter/setter pair
forcePOTTextures ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
HasMajorPerformanceCaveat → bool
no setter
hostInformation ↔ HostInformation
getter/setter pair
isFullscreen ↔ bool
getter/setter pair
isStencilEnable → bool
no setter
IsSupported → bool
no setter
needPOTTextures → bool
no setter
NpmPackage → String
no setter
onBeforeTextureInitObservable ↔ Observable<Texture>
getter/setter pair
onContextLostObservable ↔ Observable<ThinEngine>
getter/setter pair
onContextRestoredObservable ↔ Observable<ThinEngine>
getter/setter pair
premultipliedAlpha → bool
no setter
preventCacheWipeBetweenFrames ↔ bool
getter/setter pair
renderEvenInBackground ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ShadersRepository ↔ String
getter/setter pair
stencilState → StencilState
no setter
supportsUniformBuffers → bool
no setter
useReverseDepthBuffer ↔ bool
getter/setter pair
validateShaderPrograms ↔ bool
getter/setter pair
Version → String
no setter
webGLVersion → num
no setter

Methods

applyStates() → void
areAllEffectsReady() → bool
beginFrame() → void
bindArrayBuffer(DataBuffer buffer) → void
bindAttachments(List<num> attachments) → void
bindBuffers(dynamic vertexBuffers, DataBuffer indexBuffer, Effect effect) → void
bindBuffersDirectly(DataBuffer vertexBuffer, DataBuffer indexBuffer, List<num> vertexDeclaration, num vertexStrideSize, Effect effect) → void
bindFramebuffer(InternalTexture texture, [num faceIndex, num requiredWidth, num requiredHeight, bool forceFullscreenViewport, num lodLevel, num layer]) → void
bindInstancesBuffer(DataBuffer instancesBuffer, List<InstancingAttributeInfo> attributesInfo, [bool computeStride]) → void
bindSamplers(Effect effect) → void
bindUniformBlock(IPipelineContext pipelineContext, String blockName, num index) → void
bindUniformBuffer(DataBuffer buffer) → void
bindUniformBufferBase(DataBuffer buffer, num location) → void
bindVertexArrayObject(VertexArrayObject vertexArrayObject, DataBuffer indexBuffer) → void
buildTextureLayout(List<bool> textureStatus) → List<num>
clear(IColor4Like color, bool backBuffer, bool depth, [bool stencil]) → void
clearInternalTexturesCache() → void
createCubeTexture(String rootUrl, Scene scene, List<String> files, dynamic noMipmap, void onLoad(dynamic callback), void onError(String name, dynamic value), dynamic format, dynamic forcedExtension, bool createPolynomials, num lodScale, num lodOffset, InternalTexture fallback, dynamic loaderOptions) → InternalTexture
createDepthStencilTexture(RenderTargetTextureSize size, DepthTextureCreationOptions options) → InternalTexture
createDynamicTexture(num width, num height, bool generateMipMaps, num samplingMode) → InternalTexture
createDynamicUniformBuffer(Float32List elements) → DataBuffer
createDynamicVertexBuffer(ByteBuffer data) → DataBuffer
createEffect(dynamic baseName, dynamic attributesNamesOrOptions, dynamic uniformsNamesOrEngine, [List<String> samplers, String defines, IEffectFallbacks fallbacks, void onCompiled(Effect effect), void onError(Effect effect, String errors), dynamic indexParameters]) → Effect
createIndexBuffer(Int32List indices, [bool updatable]) → DataBuffer
createMultipleRenderTarget(dynamic size, IMultiRenderTargetOptions options) → List<InternalTexture>
createPipelineContext() → IPipelineContext
createPrefilteredCubeTexture(String rootUrl, Scene scene, num lodScale, num lodOffset, [void onLoad(InternalTexture multiviewTexture), void onError(String name, dynamic value), num format, dynamic forcedExtension, bool createPolynomials]) → InternalTexture
createRawCubeTexture(List<List> data, num size, num format, num type, bool generateMipMaps, bool invertY, num samplingMode, String compression) → InternalTexture
createRawShaderProgram(IPipelineContext pipelineContext, String vertexCode, String fragmentCode, [RenderingContext context, List<String> transformFeedbackVaryings]) → Program
createRawTexture(List data, num width, num height, num format, bool generateMipMaps, bool invertY, num samplingMode, String compression, num type) → InternalTexture
createRawTexture2DArray(List data, num width, num height, num depth, num format, bool generateMipMaps, bool invertY, num samplingMode, String compression, num textureType) → InternalTexture
createRawTexture3D(List data, num width, num height, num depth, num format, bool generateMipMaps, bool invertY, num samplingMode, String compression, num textureType) → InternalTexture
createRenderTargetCubeTexture(num size, [RenderTargetCreationOptions options]) → InternalTexture
createRenderTargetTexture(RenderTargetTextureSize size, dynamic options) → InternalTexture
createShaderProgram(IPipelineContext pipelineContext, String vertexCode, String fragmentCode, String defines, [RenderingContext context, List<String> transformFeedbackVaryings]) → Program
createTexture(String url, bool noMipmap, bool invertY, ISceneLike scene, [num samplingMode, void onLoad(), void onError(String name, dynamic value), dynamic buffer, InternalTexture fallback, num format, String forcedExtension, String mimeType, dynamic loaderOptions]) → InternalTexture
createUniformBuffer(Float32List elements) → DataBuffer
createVertexBuffer(ByteBuffer data) → DataBuffer
disableAttributeByIndex(num attributeLocation) → void
disableInstanceAttribute(num attributeLocation) → void
disableInstanceAttributeByName(String name) → void
dispose() → void
draw(bool useTriangles, num indexStart, num indexCount, [num instancesCount]) → void
drawArraysType(num fillMode, num verticesStart, num verticesCount, [num instancesCount]) → void
drawElementsType(num fillMode, num indexStart, num indexCount, [num instancesCount]) → void
drawPointClouds(num verticesStart, num verticesCount, [num instancesCount]) → void
drawUnIndexed(bool useTriangles, num verticesStart, num verticesCount, [num instancesCount]) → void
enableEffect(Effect effect) → void
endFrame() → void
flushFramebuffer() → void
getAlphaEquation() → num
getAlphaMode() → num
getAttributes(IPipelineContext pipelineContext, List<String> attributesNames) → List<num>
getCaps() → EngineCapabilities
getClassName() → String
getColorWrite() → bool
getError() → num
getHardwareScalingLevel() → num
getHostDocument() → Document
getHostWindow() → Window
getLoadedTexturesCache() → List<InternalTexture>
getRenderHeight([bool useScreen]) → num
getRenderingCanvas() → CanvasElement
getRenderWidth([bool useScreen]) → num
getUniforms(IPipelineContext pipelineContext, List<String> uniformsNames) → List<UniformLocation>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readPixels(num x, num y, num width, num height, [bool hasAlpha]) → Uint8List
recordVertexArrayObject(dynamic vertexBuffers, DataBuffer indexBuffer, Effect effect) → VertexArrayObject
releaseEffects() → void
releaseVertexArrayObject(VertexArrayObject vao) → void
resetTextureCache() → void
resize() → void
restoreDefaultFramebuffer() → void
restoreSingleAttachment() → void
runRenderLoop(void renderFunction()) → void
setAlphaConstants(num r, num g, num b, num a) → void
setAlphaEquation(num equation) → void
setAlphaMode(num mode, [bool noDepthWriteChange]) → void
setArray(UniformLocation uniform, dynamic array) → bool
setArray2(UniformLocation uniform, dynamic array) → bool
setArray3(UniformLocation uniform, dynamic array) → bool
setArray4(UniformLocation uniform, dynamic array) → bool
setColorWrite(bool enable) → void
setFloat(UniformLocation uniform, num value) → bool
setFloat2(UniformLocation uniform, num x, num y) → bool
setFloat3(UniformLocation uniform, num x, num y, num z) → bool
setFloat4(UniformLocation uniform, num x, num y, num z, num w) → bool
setHardwareScalingLevel(num level) → void
setInt(UniformLocation uniform, num value) → bool
setIntArray(UniformLocation uniform, Int32List array) → bool
setIntArray2(UniformLocation uniform, Int32List array) → bool
setIntArray3(UniformLocation uniform, Int32List array) → bool
setIntArray4(UniformLocation uniform, Int32List array) → bool
setMatrices(UniformLocation uniform, Float32List matrices) → bool
setMatrix2x2(UniformLocation uniform, Float32List matrix) → bool
setMatrix3x3(UniformLocation uniform, Float32List matrix) → bool
setSize(num width, num height) → bool
setTexture(num channel, UniformLocation uniform, ThinTexture texture) → void
setTextureArray(num channel, UniformLocation uniform, List<ThinTexture> textures) → void
setViewport(IViewportLike viewport, [num requiredWidth, num requiredHeight]) → void
stopRenderLoop([void renderFunction()]) → void
toString() → String
A string representation of this object.
inherited
unbindAllAttributes() → void
unbindAllTextures() → void
unBindFramebuffer(InternalTexture texture, [bool disableGenerateMipMaps, void onBeforeUnbind()]) → void
unbindInstanceAttributes() → void
unBindMultiColorAttachmentFramebuffer(List<InternalTexture> textures, bool disableGenerateMipMaps, [void onBeforeUnbind()]) → void
updateAndBindInstancesBuffer(DataBuffer instancesBuffer, Float32List data, dynamic offsetLocations) → void
updateArrayBuffer(Float32List data) → void
updateDynamicIndexBuffer(DataBuffer indexBuffer, Int32List indices, [num offset]) → void
updateDynamicTexture(InternalTexture texture, dynamic source, [bool invertY, bool premulAlpha, num format, bool forceBindTexture]) → void
updateDynamicVertexBuffer(DataBuffer vertexBuffer, ByteBuffer data, [num byteOffset, num byteLength]) → void
updateMultipleRenderTargetTextureSampleCount(List<InternalTexture> textures, num samples) → num
updateRawCubeTexture(InternalTexture texture, List<List> data, num format, num type, bool invertY) → void
updateRawTexture(InternalTexture texture, List data, num format, bool invertY) → void
updateRawTexture2DArray(InternalTexture texture, List data, num format, bool invertY) → void
updateRawTexture3D(InternalTexture texture, List data, num format, bool invertY) → void
updateTextureData(InternalTexture texture, List imageData, num xOffset, num yOffset, num width, num height, [num faceIndex, num lod]) → void
updateTextureSamplingMode(num samplingMode, InternalTexture texture, [bool generateMipMaps]) → void
updateTextureWrappingMode(InternalTexture texture, num wrapU, [num wrapV, num wrapR]) → void
updateUniformBuffer(DataBuffer uniformBuffer, Float32List elements, [num offset, num count]) → void
updateVideoTexture(InternalTexture texture, VideoElement video, bool invertY) → void
wipeCaches([bool bruteForce]) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

CollisionsEpsilon ↔ num
getter/setter pair

Static Methods

CeilingPOT(num x) → num
FloorPOT(num x) → num
GetExponentOfTwo(num value, num max, [num mode]) → num
isSupported() → bool
NearestPOT(num x) → num
QueueNewFrame(void func(), [dynamic requester]) → num