ThinSprite class

class ThinSprite

Implementers
Annotations
  • @JS.new()

Constructors

ThinSprite()

Properties

angle ↔ num
getter/setter pair
animationStarted → bool
no setter
cellIndex ↔ num
getter/setter pair
cellRef ↔ String
getter/setter pair
color ↔ IColor4Like
getter/setter pair
delay → num
no setter
fromIndex → num
no setter
hashCode → int
The hash code for this object.
no setterinherited
height ↔ num
getter/setter pair
invertU ↔ bool
getter/setter pair
invertV ↔ bool
getter/setter pair
isVisible ↔ bool
getter/setter pair
loopAnimation → bool
no setter
position ↔ IVector3Like
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toIndex → num
no setter
width ↔ num
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
playAnimation(num from, num to, bool loop, num delay, void onAnimationEnd()) → void
stopAnimation() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited