ThinTexture class

class ThinTexture

Implementers
Annotations
  • @JS.new()

Constructors

ThinTexture()
ThinTexture.args(InternalTexture internalTexture)

Properties

anisotropicFilteringLevel ↔ num
getter/setter pair
coordinatesMode → num
no setter
delayLoadState ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
is2DArray ↔ bool
getter/setter pair
is3D ↔ bool
getter/setter pair
isCube ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wrapR ↔ num
getter/setter pair
wrapU ↔ num
getter/setter pair
wrapV ↔ num
getter/setter pair

Methods

delayLoad() → void
dispose() → void
getBaseSize() → ISize
getClassName() → String
getInternalTexture() → InternalTexture
getSize() → ISize
isReady() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseInternalTexture() → void
toString() → String
A string representation of this object.
inherited
updateSamplingMode(num samplingMode) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited