TransformNode class

class TransformNode

Inheritance
Implementers
Annotations
  • @JS.new()

Constructors

TransformNode()
TransformNode.args(String name, [Scene scene, bool isPure])

Properties

absolutePosition → Vector3
no setter
absoluteRotationQuaternion → Quaternion
no setter
absoluteScaling → Vector3
no setter
animations ↔ List<Animation>
getter/setter pairinherited
behaviors → List<Behavior<Node>>
no setterinherited
billboardMode ↔ num
getter/setter pair
doNotSerialize ↔ bool
getter/setter pairinherited
forward → Vector3
no setter
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pairinherited
ignoreNonUniformScaling ↔ bool
getter/setter pair
infiniteDistance ↔ bool
getter/setter pair
isWorldMatrixFrozen → bool
no setter
metadata ↔ dynamic
getter/setter pairinherited
name ↔ String
getter/setter pairinherited
nonUniformScaling → bool
no setter
onAfterWorldMatrixUpdateObservable ↔ Observable<TransformNode>
getter/setter pair
onDispose ← void Function()
no getterinherited
onDisposeObservable ↔ Observable<Node>
getter/setter pairinherited
onReady ↔ void Function(Node node)
getter/setter pairinherited
parent ↔ Node
getter/setter pairinherited
position ↔ Vector3
getter/setter pair
preserveParentRotationForBillboard ↔ bool
getter/setter pair
reIntegrateRotationIntoRotationQuaternion ↔ bool
getter/setter pair
reservedDataStore ↔ dynamic
getter/setter pairinherited
no setter
rotation ↔ Vector3
getter/setter pair
rotationQuaternion ↔ Quaternion
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaling ↔ Vector3
getter/setter pair
scalingDeterminant ↔ num
getter/setter pair
state ↔ String
getter/setter pairinherited
uniqueId ↔ num
getter/setter pairinherited
up → Vector3
no setter
worldMatrixFromCache → Matrix
no setterinherited

Methods

addBehavior(Behavior<Node> behavior) → Node
inherited
addRotation(num x, num y, num z) → TransformNode
attachToBone(Bone bone, TransformNode affectedTransformNode) → TransformNode
clone(String name, Node newParent, [bool doNotCloneChildren]) → TransformNode
computeWorldMatrix([bool force]) → Matrix
override
createAnimationRange(String name, num from, num to) → void
inherited
deleteAnimationRange(String name, [bool deleteFrames]) → void
inherited
detachFromBone() → TransformNode
dispose([bool doNotRecurse, bool disposeMaterialAndTextures]) → void
override
freezeWorldMatrix([Matrix newWorldMatrix]) → TransformNode
getAbsolutePivotPoint() → Vector3
getAbsolutePivotPointToRef(Vector3 result) → TransformNode
getAbsolutePosition() → Vector3
getAnimationByName(String name) → Animation
inherited
getBehaviorByName(String name) → Behavior<Node>
inherited
getChildMeshes([bool directDescendantsOnly, bool predicate(Node node)]) → List<AbstractMesh>
inherited
getChildren([bool predicate(Node node), bool directDescendantsOnly]) → List<Node>
inherited
getChildTransformNodes([bool directDescendantsOnly, bool predicate(Node node)]) → List<TransformNode>
getClassName() → String
override
getDescendants([bool directDescendantsOnly, bool predicate(Node node)]) → List<Node>
inherited
getDirection(Vector3 localAxis) → Vector3
getDirectionToRef(Vector3 localAxis, Vector3 result) → TransformNode
getDistanceToCamera([Camera camera]) → num
getEngine() → Engine
inherited
getPivotMatrix() → Matrix
getPivotPoint() → Vector3
getPivotPointToRef(Vector3 result) → TransformNode
getPoseMatrix() → Matrix
getPositionExpressedInLocalSpace() → Vector3
getPositionInCameraSpace([Camera camera]) → Vector3
getScene() → Scene
inherited
getWorldMatrix() → Matrix
inherited
instantiateHierarchy([TransformNode newParent, TransformNodeInstantiateHierarchyOptions options, void onNewNodeCreated(TransformNode source, TransformNode clone)]) → TransformNode
isDescendantOf(Node ancestor) → bool
inherited
isDisposed() → bool
inherited
isEnabled([bool checkAncestors]) → bool
inherited
isReady([bool completeCheck]) → bool
inherited
isSynchronized() → bool
inherited
isSynchronizedWithParent() → bool
inherited
locallyTranslate(Vector3 vector3) → TransformNode
lookAt(Vector3 targetPoint, [num yawCor, num pitchCor, num rollCor, Space space]) → TransformNode
markAsDirty(String property) → TransformNode
normalizeToUnitCube([bool includeDescendants, bool ignoreRotation, bool predicate(AbstractMesh node)]) → TransformNode
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerAfterWorldMatrixUpdate(void func(TransformNode mesh)) → TransformNode
removeBehavior(Behavior<Node> behavior) → Node
inherited
resetLocalMatrix([bool independentOfChildren]) → void
rotate(Vector3 axis, num amount, [Space space]) → TransformNode
rotateAround(Vector3 point, Vector3 axis, num amount) → TransformNode
serialize([dynamic currentSerializationObject]) → dynamic
serializeAnimationRanges() → dynamic
inherited
setAbsolutePosition(Vector3 absolutePosition) → TransformNode
setDirection(Vector3 localAxis, [num yawCor, num pitchCor, num rollCor]) → TransformNode
setEnabled(bool value) → void
inherited
setParent(Node node) → TransformNode
setPivotMatrix(Matrix matrix, [bool postMultiplyPivotMatrix]) → TransformNode
setPivotPoint(Vector3 point, [Space space]) → TransformNode
setPositionWithLocalVector(Vector3 vector3) → TransformNode
setPreTransformMatrix(Matrix matrix) → TransformNode
toString() → String
A string representation of this object.
inherited
translate(Vector3 axis, num distance, [Space space]) → TransformNode
unfreezeWorldMatrix() → TransformNode
unregisterAfterWorldMatrixUpdate(void func(TransformNode mesh)) → TransformNode
updateCache([bool force]) → void
inherited
updatePoseMatrix(Matrix matrix) → TransformNode

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

BILLBOARDMODE_ALL ↔ num
getter/setter pair
BILLBOARDMODE_NONE ↔ num
getter/setter pair
BILLBOARDMODE_USE_POSITION ↔ num
getter/setter pair
BILLBOARDMODE_X ↔ num
getter/setter pair
BILLBOARDMODE_Y ↔ num
getter/setter pair
BILLBOARDMODE_Z ↔ num
getter/setter pair

Static Methods

Parse(dynamic parsedTransformNode, Scene scene, String rootUrl) → TransformNode