VertexBuffer class

class VertexBuffer

Annotations
  • @JS.new()

Constructors

VertexBuffer()

Properties

byteOffset → num
no setter
byteStride → num
no setter
hashCode → int
The hash code for this object.
no setterinherited
instanceDivisor ↔ num
getter/setter pair
normalized → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → num
no setter

Methods

create([ByteBuffer data]) → void
dispose() → void
forEach(num count, void callback(num rgb, num alpha)) → void
getBuffer() → DataBuffer
getData() → ByteBuffer
getInstanceDivisor() → num
getIsInstanced() → bool
getKind() → String
getOffset() → num
getSize() → num
getStrideSize() → num
isUpdatable() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(ByteBuffer data) → void
updateDirectly(ByteBuffer data, num offset, [bool useBytes]) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

BYTE → num
no setter
ColorKind → String
no setter
FLOAT → num
no setter
INT → num
no setter
MatricesIndicesExtraKind → String
no setter
MatricesIndicesKind → String
no setter
MatricesWeightsExtraKind → String
no setter
MatricesWeightsKind → String
no setter
NormalKind → String
no setter
PositionKind → String
no setter
SHORT → num
no setter
TangentKind → String
no setter
UNSIGNED_BYTE → num
no setter
UNSIGNED_INT → num
no setter
UNSIGNED_SHORT → num
no setter
UV2Kind → String
no setter
UV3Kind → String
no setter
UV4Kind → String
no setter
UV5Kind → String
no setter
UV6Kind → String
no setter
UVKind → String
no setter

Static Methods

DeduceStride(String kind) → num
ForEach(ByteBuffer data, num byteOffset, num byteStride, num componentCount, num componentType, num count, bool normalized, void callback(num rgb, num alpha)) → void
GetTypeByteLength(num type) → num