VertexDataComputeNormalsOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

VertexDataComputeNormalsOptions({dynamic facetNormals, dynamic facetPositions, dynamic facetPartitioning, num ratio, dynamic bInfo, Vector3 bbSize, dynamic subDiv, bool useRightHandedSystem, bool depthSort, Vector3 distanceTo, dynamic depthSortedFacets})
factory

Properties

bbSize → Vector3
no setter
bInfo → dynamic
no setter
depthSort → bool
no setter
depthSortedFacets → dynamic
no setter
distanceTo → Vector3
no setter
facetNormals → dynamic
no setter
facetPartitioning → dynamic
no setter
facetPositions → dynamic
no setter
hashCode → int
The hash code for this object.
no setterinherited
ratio → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subDiv → dynamic
no setter
useRightHandedSystem → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited