VertexDataCreateBoxOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

VertexDataCreateBoxOptions({num size, num width, num height, num depth, List<Vector4> faceUV, List<Color4> faceColors, num sideOrientation, Vector4 frontUVs, Vector4 backUVs})
factory

Properties

backUVs → Vector4
no setter
depth → num
no setter
faceColors → List<Color4>
no setter
faceUV → List<Vector4>
no setter
frontUVs → Vector4
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sideOrientation → num
no setter
size → num
no setter
width → num
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited