VertexDataCreateGroundFromHeightMapOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

VertexDataCreateGroundFromHeightMapOptions({num width, num height, num subdivisions, num minHeight, num maxHeight, Color3 colorFilter, Uint8List buffer, num bufferWidth, num bufferHeight, num alphaFilter})
factory

Properties

alphaFilter → num
no setter
buffer → Uint8List
no setter
bufferHeight → num
no setter
bufferWidth → num
no setter
colorFilter → Color3
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → num
no setter
maxHeight → num
no setter
minHeight → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subdivisions → num
no setter
width → num
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited