VertexDataCreateGroundOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

VertexDataCreateGroundOptions({num width, num height, num subdivisions, num subdivisionsX, num subdivisionsY})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subdivisions → num
no setter
subdivisionsX → num
no setter
subdivisionsY → num
no setter
width → num
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited