VertexDataCreateIcoSphereOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

VertexDataCreateIcoSphereOptions({num radius, num radiusX, num radiusY, num radiusZ, bool flat, num subdivisions, num sideOrientation, Vector4 frontUVs, Vector4 backUVs})
factory

Properties

backUVs → Vector4
no setter
flat → bool
no setter
frontUVs → Vector4
no setter
hashCode → int
The hash code for this object.
no setterinherited
radius → num
no setter
radiusX → num
no setter
radiusY → num
no setter
radiusZ → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sideOrientation → num
no setter
subdivisions → num
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited