VertexDataCreateTiledBoxOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

VertexDataCreateTiledBoxOptions({num pattern, num width, num height, num depth, num tileSize, num tileWidth, num tileHeight, num alignHorizontal, num alignVertical, List<Vector4> faceUV, List<Color4> faceColors, num sideOrientation})
factory

Properties

alignHorizontal → num
no setter
alignVertical → num
no setter
depth → num
no setter
faceColors → List<Color4>
no setter
faceUV → List<Vector4>
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → num
no setter
pattern → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sideOrientation → num
no setter
tileHeight → num
no setter
tileSize → num
no setter
tileWidth → num
no setter
width → num
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited