VertexDataCreateTiledGroundOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

VertexDataCreateTiledGroundOptions({num xmin, num zmin, num xmax, num zmax, VertexDataCreateTiledGroundOptions subdivisions, VertexDataCreateTiledGroundOptions precision})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
precision → VertexDataCreateTiledGroundOptionsPrecision
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subdivisions → VertexDataCreateTiledGroundOptionsSubdivisions
no setter
xmax → num
no setter
xmin → num
no setter
zmax → num
no setter
zmin → num
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited