VertexDataCreateTiledPlaneOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

VertexDataCreateTiledPlaneOptions({num pattern, num tileSize, num tileWidth, num tileHeight, num size, num width, num height, num alignHorizontal, num alignVertical, num sideOrientation, Vector4 frontUVs, Vector4 backUVs})
factory

Properties

alignHorizontal → num
no setter
alignVertical → num
no setter
backUVs → Vector4
no setter
frontUVs → Vector4
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → num
no setter
pattern → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sideOrientation → num
no setter
size → num
no setter
tileHeight → num
no setter
tileSize → num
no setter
tileWidth → num
no setter
width → num
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited