VertexDataCreateTorusKnotOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

VertexDataCreateTorusKnotOptions({num radius, num tube, num radialSegments, num tubularSegments, num p, num q, num sideOrientation, Vector4 frontUVs, Vector4 backUVs})
factory

Properties

backUVs → Vector4
no setter
frontUVs → Vector4
no setter
hashCode → int
The hash code for this object.
no setterinherited
p → num
no setter
q → num
no setter
radialSegments → num
no setter
radius → num
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sideOrientation → num
no setter
tube → num
no setter
tubularSegments → num
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited