VertexDataCreateTorusOptions class

Annotations
  • @JS.new()
  • @anonymous

Constructors

VertexDataCreateTorusOptions({num diameter, num thickness, num tessellation, num sideOrientation, Vector4 frontUVs, Vector4 backUVs})
factory

Properties

backUVs → Vector4
no setter
diameter → num
no setter
frontUVs → Vector4
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sideOrientation → num
no setter
tessellation → num
no setter
thickness → num
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited