Viewport class

class Viewport

Annotations
  • @JS.new()

Constructors

Viewport(num x, num y, num width, num height)

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ num
getter/setter pair
x ↔ num
getter/setter pair
y ↔ num
getter/setter pair

Methods

clone() → Viewport
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toGlobal(num renderWidth, num renderHeight) → Viewport
toGlobalToRef(num renderWidth, num renderHeight, Viewport ref) → Viewport
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited